@@ -17,19 +17,17 @@ from beartype.roar._roarexc import _BeartypeCallHintPepRaiseException
 from beartype._cave._cavemap import NoneTypeOr
 from beartype._data.hint.pep.sign.datapepsignset import (
     HINT_SIGNS_SUPPORTED_DEEP,
-    HINT_SIGNS_TYPE_STDLIB,
+    HINT_SIGNS_ORIGIN_ISINSTANCEABLE,
 )
-from beartype._util.hint.utilhintget import get_hint_reduced
 from beartype._util.hint.pep.utilpepget import (
     get_hint_pep_args,
-    get_hint_pep_generic_bases_unerased,
     get_hint_pep_sign,
 )
 from beartype._util.hint.pep.utilpeptest import (
     is_hint_pep,
-    is_hint_pep_generic,
-    is_hint_pep_subscripted,
+    is_hint_pep_args,
 )
+from beartype._util.hint.utilhintconv import sanify_hint_child
 from beartype._util.hint.utilhinttest import is_hint_ignorable
 from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_7
 from typing import Any, Callable, Optional, Tuple
@@ -52,7 +50,7 @@ class CauseSleuth(object):
         line of the string returned by this getter if this string spans
         multiple lines *or* ignored otherwise (i.e., if this string is instead
         embedded in the current line).
-    exception_label : str
+    exception_prefix : str
         Human-readable label describing the parameter or return value from
         which this object originates, typically embedded in exceptions raised
         from this getter in the event of unexpected runtime failure.
@@ -98,7 +96,7 @@ class CauseSleuth(object):
     # * Minimize space and time complexity.
     __slots__ = (
         'cause_indent',
-        'exception_label',
+        'exception_prefix',
         'func',
         'hint_sign',
         'hint_childs',
@@ -110,7 +108,7 @@ class CauseSleuth(object):
 
     _INIT_PARAM_NAMES = frozenset((
         'cause_indent',
-        'exception_label',
+        'exception_prefix',
         'func',
         'hint',
         'pith',
@@ -132,7 +130,7 @@ class CauseSleuth(object):
         pith: Any,
         hint: Any,
         cause_indent: str,
-        exception_label: str,
+        exception_prefix: str,
         random_int: int,
     ) -> None:
         '''
@@ -141,8 +139,8 @@ class CauseSleuth(object):
         assert callable(func), f'{repr(func)} not callable.'
         assert isinstance(cause_indent, str), (
             f'{repr(cause_indent)} not string.')
-        assert isinstance(exception_label, str), (
-            f'{repr(exception_label)} not string.')
+        assert isinstance(exception_prefix, str), (
+            f'{repr(exception_prefix)} not string.')
         assert isinstance(random_int, NoneTypeOr[int]), (
             f'{repr(random_int)} not integer or "None".')
 
@@ -150,7 +148,7 @@ class CauseSleuth(object):
         self.func = func
         self.pith = pith
         self.cause_indent = cause_indent
-        self.exception_label = exception_label
+        self.exception_prefix = exception_prefix
         self.random_int = random_int
 
         # Nullify all remaining parameters for safety.
@@ -178,22 +176,16 @@ class CauseSleuth(object):
 
         # Reduce the currently visited hint to a lower-level hint-like object
         # associated with this hint if this hint satisfies a condition.
-        hint = get_hint_reduced(hint=hint, hint_label=self.exception_label)
+        hint = sanify_hint_child(
+            hint=hint, exception_prefix=self.exception_prefix)
 
         # If this hint is PEP-compliant...
         if is_hint_pep(hint):
             # Arbitrary object uniquely identifying this hint.
             self.hint_sign = get_hint_pep_sign(hint)
 
-            # Tuple of either...
-            self.hint_childs = (
-                # If this hint is a generic, the one or more unerased
-                # pseudo-superclasses originally subclassed by this hint.
-                get_hint_pep_generic_bases_unerased(hint)
-                if is_hint_pep_generic(hint) else
-                # Else, the zero or more arguments subscripting this hint.
-                get_hint_pep_args(hint)
-            )
+            # Tuple of the zero or more arguments subscripting this hint.
+            self.hint_childs = get_hint_pep_args(hint)
 
         # Classify this hint *AFTER* all other assignments above.
         self._hint = hint
@@ -272,29 +264,29 @@ class CauseSleuth(object):
             if isinstance(self.hint, tuple):
                 # Avoid circular import dependencies.
                 from beartype._decor._error._errortype import (
-                    get_cause_or_none_types)
+                    get_cause_or_none_instance_types_tuple)
 
                 # Defer to the getter function specific to tuple unions.
-                get_cause_or_none = get_cause_or_none_types
+                get_cause_or_none = get_cause_or_none_instance_types_tuple
             # Else, this hint *NOT* is a tuple union. In this case, assume this
             # hint to be an isinstanceable class. If this is *NOT* the case,
             # the getter deferred to below raises a human-readable exception.
             else:
                 # Avoid circular import dependencies.
                 from beartype._decor._error._errortype import (
-                    get_cause_or_none_type)
+                    get_cause_or_none_instance_type)
 
                 # Defer to the getter function specific to classes.
-                get_cause_or_none = get_cause_or_none_type
+                get_cause_or_none = get_cause_or_none_instance_type
         # Else, this hint is PEP-compliant.
         #
         # If this hint is neither...
         elif (
             # Originates from an origin type and may thus be shallowly
             # type-checked against that type *AND is either...
-            self.hint_sign in HINT_SIGNS_TYPE_STDLIB and (
+            self.hint_sign in HINT_SIGNS_ORIGIN_ISINSTANCEABLE and (
                 #FIXME: Ideally, this line should just resemble:
-                #    not is_hint_pep_subscripted(hint_curr)
+                #    not is_hint_pep_args(hint_curr)
                 #Unfortunately, unsubscripted type hints under Python 3.6
                 #like "typing.List" are technically subscripted due to
                 #subclassing subscripted superclasses, which is insane. Due
@@ -303,7 +295,7 @@ class CauseSleuth(object):
                 #drop this as soon as we drop Python 3.6 support.
                 # Unsubscripted *OR*...
                 not (
-                    is_hint_pep_subscripted(self.hint)
+                    is_hint_pep_args(self.hint)
                     if IS_PYTHON_AT_LEAST_3_7 else
                     len(self.hint_childs)
                 ) or
@@ -317,11 +309,11 @@ class CauseSleuth(object):
         ):
             # Avoid circular import dependencies.
             from beartype._decor._error._errortype import (
-                get_cause_or_none_type_stdlib)
+                get_cause_or_none_type_instance_origin)
 
             # Defer to the getter function supporting hints originating
             # from origin types.
-            get_cause_or_none = get_cause_or_none_type_stdlib
+            get_cause_or_none = get_cause_or_none_type_instance_origin
         # Else, this hint is either subscripted *OR* unsubscripted but not
         # originating from a standard type origin. In either case, this hint
         # was type-checked deeply.
@@ -339,7 +331,7 @@ class CauseSleuth(object):
             # yet, raise an exception.
             if get_cause_or_none is None:
                 raise _BeartypeCallHintPepRaiseException(
-                    f'{self.exception_label} type hint '
+                    f'{self.exception_prefix} type hint '
                     f'{repr(self.hint)} unsupported (i.e., no '
                     f'"get_cause_or_none_"-prefixed getter function defined '
                     f'for this category of hint).'
@@ -380,7 +372,7 @@ class CauseSleuth(object):
             ...     pith=[42,]
             ...     hint=typing.List[int],
             ...     cause_indent='',
-            ...     exception_label='List of integers',
+            ...     exception_prefix='List of integers',
             ... )
             >>> sleuth_copy = sleuth.permute(pith=[24,])
             >>> sleuth_copy.pith
