@@ -74,25 +74,6 @@ from beartype.roar._roarexc import (
     _BeartypeCallHintPepRaiseDesynchronizationException,
 )
 from beartype._cave._cavemap import NoneTypeOr
-from beartype._decor._error._errorgeneric import (
-    get_cause_or_none_generic)
-from beartype._decor._error._errorsequence import (
-    get_cause_or_none_sequence_args_1,
-    get_cause_or_none_tuple,
-)
-from beartype._decor._error._errorsleuth import CauseSleuth
-from beartype._decor._error._errortype import (
-    get_cause_or_none_forwardref,
-    get_cause_or_none_type_stdlib,
-)
-from beartype._decor._error._proposal._errorpep484noreturn import (
-    get_cause_or_none_noreturn)
-from beartype._decor._error._proposal._errorpep484union import (
-    get_cause_or_none_union)
-from beartype._decor._error._proposal._errorpep586 import (
-    get_cause_or_none_literal)
-from beartype._decor._error._proposal._errorpep593 import (
-    get_cause_or_none_annotated)
 from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._data.hint.pep.sign.datapepsigns import (
     HintSignAnnotated,
@@ -101,20 +82,23 @@ from beartype._data.hint.pep.sign.datapepsigns import (
     HintSignLiteral,
     HintSignNoReturn,
     HintSignTuple,
+    HintSignType,
 )
 from beartype._data.hint.pep.sign.datapepsignset import (
     HINT_SIGNS_SEQUENCE_ARGS_1,
-    HINT_SIGNS_TYPE_STDLIB,
+    HINT_SIGNS_ORIGIN_ISINSTANCEABLE,
     HINT_SIGNS_UNION,
 )
+from beartype._decor._error._errorsleuth import CauseSleuth
 from beartype._util.hint.utilhinttest import die_unless_hint
 from beartype._util.text.utiltextlabel import (
-    label_callable_decorated_param_value,
-    label_callable_decorated_return_value,
+    prefix_callable_decorated_param_value,
+    prefix_callable_decorated_return_value,
 )
 from beartype._util.text.utiltextmunge import suffix_unless_suffixed
 from beartype._util.text.utiltextrepr import represent_object
-from typing import Callable, Dict, NoReturn, Optional, Type
+from beartype._util.utiltyping import TypeException
+from typing import Callable, Dict, NoReturn, Optional
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
@@ -244,7 +228,7 @@ def raise_pep_call_exception(
     assert callable(func), f'{repr(func)} uncallable.'
     assert isinstance(pith_name, str), f'{repr(pith_name)} not string.'
     assert isinstance(random_int, NoneTypeOr[int]), (
-        f'{repr(random_int)} not integer or "None".')
+        f'{repr(random_int)} neither integer nor "None".')
     # print('''raise_pep_call_exception(
     #     func={!r},
     #     pith_name={!r},
@@ -252,24 +236,24 @@ def raise_pep_call_exception(
     # )'''.format(func, pith_name, pith_value))
 
     # Type of exception to be raised.
-    exception_cls: Type[Exception] = None  # type: ignore[assignment]
+    exception_cls: TypeException = None  # type: ignore[assignment]
 
     # Human-readable label describing this parameter or return value.
-    pith_label: str = None  # type: ignore[assignment]
+    exception_prefix: str = None  # type: ignore[assignment]
 
     # If the name of this parameter is the magic string implying the passed
     # object to be a return value, set the above local variables appropriately.
     if pith_name == 'return':
         exception_cls = BeartypeCallHintPepReturnException
-        pith_label = label_callable_decorated_return_value(
+        exception_prefix = prefix_callable_decorated_return_value(
             func=func, return_value=pith_value)
     # Else, the passed object is a parameter. In this case, set the above local
     # variables appropriately.
     else:
         exception_cls = BeartypeCallHintPepParamException
-        pith_label = label_callable_decorated_param_value(
+        exception_prefix = prefix_callable_decorated_param_value(
             func=func,
-            param_name =pith_name,
+            param_name=pith_name,
             param_value=pith_value,
         )
 
@@ -280,7 +264,8 @@ def raise_pep_call_exception(
     # could deface the "__annotations__" dunder dictionary without our
     # knowledge or permission, precautions are warranted.
     if pith_name not in func.__annotations__:
-        raise _BeartypeCallHintPepRaiseException(f'{pith_label} unannotated.')
+        raise _BeartypeCallHintPepRaiseException(
+            f'{exception_prefix}unannotated.')
     # Else, this parameter or return value is annotated.
 
     # PEP-compliant type hint annotating this parameter or return value.
@@ -291,7 +276,7 @@ def raise_pep_call_exception(
     # generally supported by both parameters and return values. In this case...
     if hint is not NoReturn:
         # If type hint is *NOT* a supported type hint, raise an exception.
-        die_unless_hint(hint=hint, hint_label=f'{pith_label} type hint')
+        die_unless_hint(hint=hint, exception_prefix=exception_prefix)
         # Else, this type hint is supported.
 
     # Human-readable string describing the failure of this pith to satisfy this
@@ -302,7 +287,7 @@ def raise_pep_call_exception(
         pith=pith_value,
         hint=hint,
         cause_indent='',
-        exception_label=pith_label,
+        exception_prefix=exception_prefix,
         random_int=random_int,
     ).get_cause_or_none()
 
@@ -314,7 +299,7 @@ def raise_pep_call_exception(
 
         # Raise an exception of the desired class embedding this cause.
         raise exception_cls(  # type: ignore[misc]
-            f'{pith_label} violates type hint {repr(hint)}, as '
+            f'{exception_prefix}violates type hint {repr(hint)}, as '
             f'{exception_cause_suffixed}'
         )
 
@@ -327,7 +312,7 @@ def raise_pep_call_exception(
     pith_value_repr = represent_object(
         obj=pith_value, max_len=_CAUSE_TRIM_OBJECT_REPR_MAX_LEN)
     raise _BeartypeCallHintPepRaiseDesynchronizationException(
-        f'{pith_label} violates type hint {repr(hint)}, '
+        f'{exception_prefix}violates type hint {repr(hint)}, '
         f'but utility function raise_pep_call_exception() '
         f'suggests this object satisfies this hint. '
         f'Please report this desynchronization failure to '
@@ -342,12 +327,33 @@ def _init() -> None:
     Initialize this submodule.
     '''
 
+    # Defer heavyweight imports.
+    from beartype._decor._error._errortype import (
+        get_cause_or_none_instance_type_forwardref,
+        get_cause_or_none_subclass_type,
+        get_cause_or_none_type_instance_origin,
+    )
+    from beartype._decor._error._pep._pep484._errornoreturn import (
+        get_cause_or_none_noreturn)
+    from beartype._decor._error._pep._pep484._errorunion import (
+        get_cause_or_none_union)
+    from beartype._decor._error._pep._pep484585._errorgeneric import (
+        get_cause_or_none_generic)
+    from beartype._decor._error._pep._pep484585._errorsequence import (
+        get_cause_or_none_sequence_args_1,
+        get_cause_or_none_tuple,
+    )
+    from beartype._decor._error._pep._errorpep586 import (
+        get_cause_or_none_literal)
+    from beartype._decor._error._pep._errorpep593 import (
+        get_cause_or_none_annotated)
+
     # Map each originative sign to the appropriate getter *BEFORE* any other
     # mappings. This is merely a generalized fallback subsequently replaced by
     # sign-specific getters below.
-    for pep_sign_type_origin in HINT_SIGNS_TYPE_STDLIB:
-        PEP_HINT_SIGN_TO_GET_CAUSE_FUNC[pep_sign_type_origin] = (
-            get_cause_or_none_type_stdlib)
+    for pep_sign_origin_isinstanceable in HINT_SIGNS_ORIGIN_ISINSTANCEABLE:
+        PEP_HINT_SIGN_TO_GET_CAUSE_FUNC[pep_sign_origin_isinstanceable] = (
+            get_cause_or_none_type_instance_origin)
 
     # Map each 1-argument sequence sign to its corresponding getter.
     for pep_sign_sequence_args_1 in HINT_SIGNS_SEQUENCE_ARGS_1:
@@ -364,11 +370,12 @@ def _init() -> None:
     # other automated mappings above.
     PEP_HINT_SIGN_TO_GET_CAUSE_FUNC.update({
         HintSignAnnotated: get_cause_or_none_annotated,
-        HintSignForwardRef: get_cause_or_none_forwardref,
+        HintSignForwardRef: get_cause_or_none_instance_type_forwardref,
         HintSignGeneric: get_cause_or_none_generic,
         HintSignLiteral: get_cause_or_none_literal,
         HintSignNoReturn: get_cause_or_none_noreturn,
         HintSignTuple: get_cause_or_none_tuple,
+        HintSignType: get_cause_or_none_subclass_type,
     })
 
 
