@@ -4,26 +4,18 @@
 # See "LICENSE" for further details.
 
 '''
-Project-wide **callable scope** utilities.
-
-This private submodule implements utility functions dynamically introspecting
-the possibly nested lexical scopes enclosing arbitrary callables.
+Project-wide **callable scope** utilities (i.e., functions handling the
+possibly nested lexical scopes enclosing arbitrary callables).
 
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                           }....................
-from beartype.roar._roarexc import (
-    BeartypeDecorHintNonPepException,
-    _BeartypeUtilCallableException,
-)
-from beartype._util.utilobject import (
-    get_object_scopes_name,
-    get_object_type_basename,
-)
-from collections.abc import Callable, Set
+from beartype.roar._roarexc import _BeartypeUtilCallableException
+from beartype._util.utilobject import get_object_basename_scoped
+from collections.abc import Callable
 from types import CodeType
-from typing import AbstractSet, Any, Dict, Optional, Tuple, Type, Union
+from typing import Any, Dict, Optional, Type
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
@@ -36,12 +28,6 @@ from the name to value of each locally or globally scoped variable accessible
 to a callable).
 '''
 
-# ....................{ CONSTANTS                         }....................
-_SET_OR_TUPLE = (Set, tuple)
-'''
-2-tuple containing the superclasses of all frozen sets and tuples.
-'''
-
 # ....................{ TESTERS                           }....................
 def is_func_nested(func: Callable) -> bool:
     '''
@@ -126,9 +112,7 @@ def is_func_nested(func: Callable) -> bool:
 #     assert callable(func), f'{repr(func)} not callable.'
 #
 #     # Return true only if this callable defines a closure-specific dunder
-#     # attribute.
-#     #
-#     # Note that the "__closure__" dunder variable is either:
+#     # attribute whose value is either:
 #     # * If this callable is a closure, a tuple of zero or more cell variables.
 #     # * If this callable is a pure-Python non-closure, "None".
 #     # * If this callable is C-based, undefined.
@@ -326,7 +310,7 @@ def get_func_locals(
         # Then silently reduce to a noop by treating this nested callable as
         # module-scoped by preserving "func_locals" as the empty dictionary.
         return {}
-    # Else:
+    # Else, all of the following constraints hold:
     # * The passed callable is physically declared on-disk.
     # * The passed callable is nested.
     # * The active Python interpreter declares the sys._getframe() getter.
@@ -336,46 +320,41 @@ def get_func_locals(
     func_scope: CallableScope = {}
 
     # ..................{ LOCALS ~ scope : name             }..................
-    # Unqualified name of the passed callable.
+    # Unqualified name of this nested callable.
     func_name_unqualified = func.__name__
 
-    # Fully-qualified name of the passed callable.
-    #
-    # Note that, if the passed callable is a nested non-method callable, this
-    # name contains one or more semantically meaningless placeholder substrings
+    # Fully-qualified name of this nested callable. If this nested callable is
+    # a non-method, this name contains one or more meaningless placeholders
     # "<locals>" -- each identifying one parent callable lexically containing
-    # the passed callable: e.g.,
-    #       >>> def muh_func():
-    #       ...     def muh_closure(): pass
-    #       ...     return muh_closure()
-    #       >>> muh_func().__qualname__
-    #       'muh_func.<locals>.muh_closure'
+    # this nested callable: e.g.,
+    #     >>> def muh_func():
+    #     ...     def muh_closure(): pass
+    #     ...     return muh_closure()
+    #     >>> muh_func().__qualname__
+    #     'muh_func.<locals>.muh_closure'
     func_name_qualified = func.__qualname__
 
     # Non-empty list of the unqualified names of all parent callables lexically
-    # containing the passed callable (excluding that callable itself).
+    # containing this nested callable (including this nested callable itself).
     #
     # Note that:
     # * The set of all callables embodied by the current runtime call stack is
-    #   a (typically proper) superset of the set of all callables embodied by
-    #   the lexical scopes encapsulating this nested callable. Ergo:
+    #   a (usually proper) superset of the set of all callables embodied by the
+    #   lexical scopes encapsulating this nested callable. Ergo:
     #   * Some stack frames have no corresponding lexical scopes (e.g., stack
     #     frames embodying callables defined by different modules).
     #   * *ALL* lexical scopes have a corresponding stack frame.
     # * Stack frames are only efficiently accessible relative to the initial
     #   stack frame embodying this nested callable, which resides at the end of
-    #   the call stack. This implies we *MUST* iteratively search up:
-    #   * The call stack for frames with relevant lexical scopes and ignore
-    #     intervening frames with irrelevant lexical scopes, beginning at the
-    #     end of that stack.
-    #   * Lexical scopes for scopes with corresponding frames, beginning at the
-    #     last lexical scope.
-    funcs_scopes_name = func_name_qualified.rsplit(sep='.', maxsplit=3)
+    #   the call stack. This implies we *MUST* iteratively search up the call
+    #   stack for frames with relevant lexical scopes and ignore intervening
+    #   frames with irrelevant lexical scopes, starting at the stack top (end).
+    func_scope_names = func_name_qualified.rsplit(sep='.')
 
     # Assert this nested callable is encapsulated by at least two lexical
     # scopes identifying at least this nested callable and the parent callable
     # or class declaring this nested callable.
-    assert len(funcs_scopes_name) >= 2, (
+    assert len(func_scope_names) >= 2, (
         f'{func_name_unqualified}() not nested (i.e., fully-qualified name '
         f'"{func_name_qualified}" == unqualified name '
         f'"{func_name_unqualified}").')
@@ -384,19 +363,19 @@ def get_func_locals(
     # the passed callable is *NOT* that callable itself, the caller maliciously
     # renamed one but *NOT* both of the dunder attributes of that callable
     # uniquely identifying that callable. In this case, raise an exception.
-    if funcs_scopes_name[-1] != func_name_unqualified:
+    if func_scope_names[-1] != func_name_unqualified:
         raise exception_cls(
             f'{func_name_unqualified}() fully-qualified name '
             f'{func_name_qualified}() invalid (i.e., last lexical scope '
-            f'"{funcs_scopes_name[-1]}" != unqualified name '
+            f'"{func_scope_names[-1]}" != unqualified name '
             f'"{func_name_unqualified}").'
         )
 
     # Unqualified name of the parent callable directly lexically containing
     # (and thus declaring) the passed callable -- which by the above validation
-    # is guaranteed to be the third-to-last string in this list of scope names.
+    # is guaranteed to be the second-to-last string in this list of names.
     #
-    # Note that that parent callable's local runtime scope transitively
+    # Note that that the parent callable's local runtime scope transitively
     # contains *ALL* local variables accessible to this nested callable
     # (including the local variables directly contained in the body of that
     # parent callable as well as the local variables directly contained in the
@@ -404,17 +383,20 @@ def get_func_locals(
     # scope). Since that parent callable's local runtime scope is exactly the
     # dictionary to be returned, iteration below searches up the runtime call
     # stack for a stack frame embodying that parent callable and no further.
-    func_scope_name = funcs_scopes_name[-2]
+    func_scope_name = func_scope_names[-2]
 
     # If this name is the placeholder substring specific to nested callables...
     if func_scope_name == '<locals>':
-        # If this list of unqualified names contains less than three names,
-        # by deduction this name *MUST* have been the first in this list. But
-        # this placeholder substring *MUST* be preceded by the name of a parent
-        # callable. Since this is *NOT* the case, the caller maliciously
+        # If this list contains less than three names, this list *MUST* contain
+        # exactly two names, since this list is neither empty *NOR* contains
+        # exactly one name. In this case, this name *MUST* by deduction have
+        # been the first in this list.
+        #
+        # But this placeholder substring *MUST* be preceded by the name of a
+        # parent callable. Since this is *NOT* the case, the caller maliciously
         # renamed the "__qualname__" dunder attributes of the passed callable
         # to be prefixed by "<locals>". In this case, raise an exception.
-        if len(funcs_scopes_name) < 3:
+        if len(func_scope_names) < 3:
             raise exception_cls(
                 f'{func_name_unqualified}() fully-qualified name '
                 f'{func_name_qualified}() invalid (i.e., placeholder '
@@ -423,7 +405,7 @@ def get_func_locals(
 
         # Skip over this placeholder to the unqualified name of the parent
         # callable lexically containing the passed callable.
-        func_scope_name = funcs_scopes_name[-3]
+        func_scope_name = func_scope_names[-3]
     # print(f'Searching for parent {func_scope_name}() local scope...')
 
     # ..................{ LOCALS ~ frame                    }..................
@@ -485,7 +467,7 @@ def get_func_locals(
             # raise an exception.
             if func_frame_name == '<module>':
                 raise exception_cls(
-                    f'{get_object_scopes_name(func)}() parent lexical scope '
+                    f'{get_object_basename_scoped(func)}() parent lexical scope '
                     f'{func_scope_name}() not found on call stack.'
                 )
             # Else, that scope is *NOT* a module.
@@ -546,10 +528,10 @@ def get_func_locals(
 def add_func_scope_attr(
     # Mandatory parameters.
     attr: Any,
-    attr_scope: CallableScope,
+    func_scope: CallableScope,
 
     # Optional parameters.
-    attr_label: str = 'Globally or locally scoped attribute',
+    exception_prefix: str = 'Globally or locally scoped attribute ',
 ) -> str:
     '''
     Add a new **scoped attribute** (i.e., new key-value pair of the passed
@@ -563,11 +545,11 @@ def add_func_scope_attr(
     ----------
     attr : Any
         Arbitrary object to be added to this scope.
-    attr_scope : CallableScope
-        Local or global scope to add this object as an attribute to.
-    attr_label : str, optional
-        Human-readable substring describing this object in exception messages.
-        Defaults to a reasonably sane string.
+    func_scope : CallableScope
+        Local or global scope to add this object to.
+    exception_prefix : str, optional
+        Human-readable label prefixing the representation of this object in the
+        exception message. Defaults to the empty string.
 
     Returns
     ----------
@@ -576,14 +558,16 @@ def add_func_scope_attr(
 
     Raises
     ----------
-    _BeartypeUtilCallableException
+    :exc:`_BeartypeUtilCallableException`
         If an attribute with the same name as that internally generated by
-        this getter but having a different value already exists in this scope.
-        This getter uniquifies names by object identifier and should thus
+        this adder but having a different value already exists in this scope.
+        This adder uniquifies names by object identifier and should thus
         *never* generate name collisions. This exception is thus intentionally
         raised as a private rather than public exception.
     '''
-    assert isinstance(attr_scope, dict), f'{repr(attr_scope)} not dictionary.'
+    assert isinstance(func_scope, dict), f'{repr(func_scope)} not dictionary.'
+    assert isinstance(exception_prefix, str), (
+        f'{repr(exception_prefix)} not string.')
 
     # Name of the new attribute referring to this object in this scope, mildly
     # obfuscated so as to avoid name collisions.
@@ -591,266 +575,17 @@ def add_func_scope_attr(
 
     # If an attribute with the same name but differing value already exists in
     # this scope, raise an exception.
-    if attr_scope.get(attr_name, attr) is not attr:
+    if func_scope.get(attr_name, attr) is not attr:
         raise _BeartypeUtilCallableException(
-            f'{attr_label} "{attr_name}" already exists with '
-            f'differing value:\n'
+            f'{exception_prefix}"{attr_name}" already exists with differing value:\n'
             f'~~~~[ NEW VALUE ]~~~~\n{repr(attr)}\n'
-            f'~~~~[ OLD VALUE ]~~~~\n{repr(attr_scope[attr_name])}'
+            f'~~~~[ OLD VALUE ]~~~~\n{repr(func_scope[attr_name])}'
         )
     # Else, either no attribute with this name exists in this scope *OR* an
     # attribute with this name and value already exists in this scope.
 
     # Refer to the passed object in this scope with this name.
-    attr_scope[attr_name] = attr
+    func_scope[attr_name] = attr
 
     # Return this name.
     return attr_name
-
-# ....................{ ADDERS ~ type                     }....................
-def add_func_scope_type(
-    # Mandatory parameters.
-    cls: type,
-    cls_scope: CallableScope,
-
-    # Optional parameters.
-    cls_label: str = 'Globally or locally scoped class',
-) -> str:
-    '''
-    Add a new **scoped class** (i.e., new key-value pair of the passed
-    dictionary mapping from the name to value of each globally or locally
-    scoped attribute externally accessed elsewhere, whose key is a
-    machine-readable name internally generated by this function to uniquely
-    refer to the passed class and whose value is that class) to the passed
-    scope *and* return that name.
-
-    Parameters
-    ----------
-    cls : type
-        Arbitrary class to be passed as a new parameter.
-    cls_scope : CallableScope
-        Local or global scope to add this object as an attribute to.
-    cls_label : str, optional
-        Human-readable substring describing this object in exception messages.
-        Defaults to a reasonably sane string.
-
-    Returns
-    ----------
-    str
-        Name of the passed class in this scope generated by this function.
-
-    Raises
-    ----------
-    BeartypeDecorHintPep3119Exception
-        If this class is *not* isinstanceable (i.e., passable as the second
-        argument to the :func:`isinstance` builtin).
-    _BeartypeUtilCallableException
-        If an attribute with the same name as that internally generated by
-        this getter but having a different value already exists in this scope.
-        This getter uniquifies names by object identifier and should thus
-        *never* generate name collisions. This exception is thus intentionally
-        raised as a private rather than public exception.
-    '''
-
-    # Avoid circular import dependencies.
-    from beartype._util.cls.utilclstest import (
-        die_unless_type_isinstanceable,
-        is_type_builtin,
-    )
-
-    # If this object is *NOT* an isinstanceable class, raise an exception.
-    die_unless_type_isinstanceable(cls=cls, cls_label=cls_label)
-    # Else, this object is an isinstanceable class.
-
-    # Return either...
-    return (
-        # If this type is a builtin (i.e., globally accessible C-based type
-        # requiring *no* explicit importation), the unqualified basename of
-        # this type as is, as this type requires no parametrization;
-        get_object_type_basename(cls)
-        if is_type_builtin(cls) else
-        # Else, the name of a new parameter passing this class.
-        add_func_scope_attr(
-            attr=cls, attr_scope=cls_scope, attr_label=cls_label)
-    )
-
-
-def add_func_scope_types(
-    # Mandatory parameters.
-    types: Union[AbstractSet[type], Tuple[type, ...]],
-    types_scope: CallableScope,
-
-    # Optional parameters.
-    types_label: str = 'Globally or locally scoped class',
-    is_unique: bool = False,
-) -> str:
-    '''
-    Add a new **scoped class tuple** (i.e., new key-value pair of the passed
-    dictionary mapping from the name to value of each globally or locally
-    scoped attribute externally accessed elsewhere, whose key is a
-    machine-readable name internally generated by this function to uniquely
-    refer to the passed tuple of types and whose value is that tuple) to the
-    passed scope *and* return that machine-readable name.
-
-    This function additionally caches this tuple with the beartypistry
-    singleton to reduce space consumption for tuples duplicated across the
-    active Python interpreter.
-
-    Design
-    ----------
-    Unlike types, tuples are commonly dynamically constructed on-the-fly by
-    various tuple factories (e.g., :attr:`beartype.cave.NoneTypeOr`,
-    :attr:`typing.Optional`) and hence have no reliable fully-qualified names.
-    Instead, this function caches this tuple into the beartypistry under a
-    string synthesized as the unique concatenation of:
-
-    * The magic substring :data:`TYPISTRY_HINT_NAME_TUPLE_PREFIX`. Since
-      fully-qualified classnames uniquely identifying types as beartypistry
-      keys are guaranteed to *never* contain this substring, this substring
-      prevents collisions between tuple and type names.
-    * This tuple's hash. Note that this tuple's object ID is intentionally
-      *not* embedded in this string. Two tuples with the same items are
-      typically different objects and thus have different object IDs, despite
-      producing identical hashes: e.g.,
-
-      >>> ('Das', 'Kapitel',) is ('Das', 'Kapitel',)
-      False
-      >>> id(('Das', 'Kapitel',)) == id(('Das', 'Kapitel',))
-      False
-      >>> hash(('Das', 'Kapitel',)) == hash(('Das', 'Kapitel',))
-      True
-
-    The exception is the empty tuple, which is a singleton and thus *always*
-    has the same object ID and hash: e.g.,
-
-        >>> () is ()
-        True
-        >>> id(()) == id(())
-        True
-        >>> hash(()) == hash(())
-        True
-
-    Identifying tuples by their hashes enables the beartypistry singleton to
-    transparently cache duplicate class tuples with distinct object IDs as the
-    same underlying object, reducing space consumption. While hashing tuples
-    does impact time performance, the gain in space is worth the cost.
-
-    Parameters
-    ----------
-    types : Union[AbstractSet[type], Tuple[type, ...]]
-        Set or tuple of arbitrary types to be passed as a new parameter.
-    types_scope : CallableScope
-        Local or global scope to add this object as an attribute to.
-    types_label : str, optional
-        Human-readable substring describing this object in exception messages.
-        Defaults to a reasonably sane string.
-    is_unique : bool, optional
-        ``True`` only if the caller guarantees this tuple to contain *no*
-        duplicate types. This boolean is ignored if ``types`` is a set rather
-        than tuple. Defaults to ``False``. If ``False``, this function assumes
-        this tuple to contain duplicate types by internally:
-
-        #. Coercing this tuple into a set, thus implicitly ignoring both
-           duplicates and ordering of types in this tuple.
-        #. Coercing that set back into another tuple.
-        #. If these two tuples differ, the passed tuple contains one or more
-           duplicates; in this case, the duplicate-free tuple is cached and
-           passed.
-        #. Else, the passed tuple contains no duplicates; in this case, the
-           passed tuple is cached and passed.
-
-        This boolean does *not* simply enable an edge-case optimization, though
-        it certainly does that; this boolean enables callers to guarantee that
-        this function caches and passes the passed tuple rather than a new
-        tuple internally created by this function.
-
-    Returns
-    ----------
-    str
-        Name of the passed tuple in this scope generated by this function.
-
-    Raises
-    ----------
-    BeartypeDecorHintNonPepException
-        If ``types`` is either:
-
-        * Neither a set nor tuple.
-        * A set or tuple that is empty.
-    BeartypeDecorHintPep3119Exception
-        If one or more items of ``types`` are *not* isinstanceable classes
-        (i.e., classes passable as the second argument to the
-        :func:`isinstance` builtin).
-    _BeartypeUtilCallableException
-        If an attribute with the same name as that internally generated by this
-        getter but having a different value already exists in this scope. This
-        getter uniquifies names by object identifier and should thus *never*
-        generate name collisions. This exception is thus intentionally raised
-        as a private rather than public exception.
-    '''
-    assert isinstance(is_unique, bool), f'{repr(is_unique)} not bool.'
-
-    # Avoid circular import dependencies.
-    from beartype._decor._cache.cachetype import (
-        TYPISTRY_HINT_NAME_TUPLE_PREFIX,
-        bear_typistry,
-    )
-    from beartype._util.hint.nonpep.utilnonpeptest import (
-        die_unless_hint_nonpep_type)
-
-    # If this object is neither a set nor tuple, raise an exception.
-    if not isinstance(types, _SET_OR_TUPLE):
-        raise BeartypeDecorHintNonPepException(
-            f'{types_label} {repr(types)} neither set nor tuple.')
-    # Else, this object is either a set or tuple.
-    #
-    # If this collection is empty, raise an exception.
-    elif not types:
-        raise BeartypeDecorHintNonPepException(f'{types_label} empty.')
-    # Else, this collection is non-empty.
-
-    # If any item in this collection is *NOT* a standard class, raise an
-    # exception.
-    for cls in types:
-        die_unless_hint_nonpep_type(hint=cls, hint_label=types_label)
-    # Else, all items of this collection are standard classes.
-
-    # If this tuple only contains one type, register only this type.
-    if len(types) == 1:
-        return add_func_scope_type(
-            # The first and only item of this collection, accessed as either:
-            # * If this collection is a tuple, that item with fast indexing.
-            # * If this collection is a set, that item with slow iteration.
-            cls=types[0] if isinstance(types, tuple) else next(iter(types)),
-            cls_scope=types_scope,
-            cls_label=types_label,
-        )
-    # Else, this tuple either contains two or more types.
-    #
-    # If this collection is a frozenset, coerce this frozenset into a tuple.
-    elif isinstance(types, Set):
-        types = tuple(types)
-    # If this collection is a tuple *AND* the caller failed to guarantee this
-    # tuple to be duplicate-free, coerce this tuple into (in order):
-    # * A set, thus ignoring duplicates and ordering.
-    # * Back into a duplicate-free tuple.
-    elif isinstance(types, tuple) and not is_unique:
-        types = tuple(set(types))
-    # In either case, this collection is now guaranteed to be a tuple
-    # containing only duplicate-free classes.
-    assert isinstance(types, tuple), f'{types_label} {repr(types)} not tuple.'
-
-    # Name uniquely identifying this collection as a beartypistry key.
-    tuple_types_name = f'{TYPISTRY_HINT_NAME_TUPLE_PREFIX}{hash(types)}'
-
-    # If this tuple has *NOT* already been cached with the beartypistry
-    # singleton, do so.
-    if tuple_types_name not in bear_typistry:
-        bear_typistry[tuple_types_name] = types
-    # Else, this tuple has already been cached with the beartypistry
-    # singleton. In this case, reuse the previously cached tuple.
-    else:
-        types = bear_typistry[tuple_types_name]
-
-    # Return the name of a new parameter passing this tuple.
-    return add_func_scope_attr(
-        attr=types, attr_scope=types_scope, attr_label=types_label)
