@@ -17,13 +17,13 @@ This private submodule is *not* intended for importation by downstream callers.
 #    from beartype._util.mod.utilmodule import die_unless_module_attr_name
 
 # ....................{ IMPORTS                           }....................
-from beartype.roar import BeartypeDecorHintNonPepException
+from beartype.roar import BeartypeDecorHintNonpepException
 from beartype._util.cache.utilcachecall import callable_cached
-from beartype._util.cls.utilclstest import (
+from beartype._util.cls.pep.utilpep3119 import (
     die_unless_type_isinstanceable,
     is_type_isinstanceable,
 )
-from typing import Type
+from beartype._util.utiltyping import TypeException
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
@@ -35,9 +35,9 @@ def die_if_hint_nonpep(
     hint: object,
 
     # Optional parameters.
-    hint_label: str = 'Type hint',
     is_str_valid: bool = True,
-    exception_cls: Type[Exception] = BeartypeDecorHintNonPepException,
+    exception_cls: TypeException = BeartypeDecorHintNonpepException,
+    exception_prefix: str = '',
 ) -> None:
     '''
     Raise an exception if the passed object is a **PEP-noncompliant type hint**
@@ -51,10 +51,7 @@ def die_if_hint_nonpep(
     ----------
     hint : object
         Object to be validated.
-    hint_label : Optional[str]
-        Human-readable label prefixing this object's representation in the
-        exception message raised by this function. Defaults to ``Type hint``.
-    is_str_valid : Optional[bool]
+    is_str_valid : bool, optional
         ``True`` only if this function permits this object to either be a
         string or contain strings. Defaults to ``True``. If this boolean is:
 
@@ -62,9 +59,12 @@ def die_if_hint_nonpep(
           or tuple of classes and/or classnames.
         * ``False``, this object is valid only if this object is either a class
           or tuple of classes.
-    exception_cls : Optional[type]
+    exception_cls : type[Exception]
         Type of the exception to be raised by this function. Defaults to
-        :class:`BeartypeDecorHintNonPepException`.
+        :class:`BeartypeDecorHintNonpepException`.
+    exception_prefix : str, optional
+        Human-readable label prefixing the representation of this object in the
+        exception message. Defaults to the empty string.
 
     Raises
     ----------
@@ -87,12 +87,14 @@ def die_if_hint_nonpep(
     # Note that this memoized call is intentionally passed positional rather
     # than keyword parameters to maximize efficiency.
     if is_hint_nonpep(hint, is_str_valid):
-        assert isinstance(hint_label, str), f'{repr(hint_label)} not string.'
+        assert isinstance(exception_prefix, str), (
+            f'{repr(exception_prefix)} not string.')
         assert isinstance(exception_cls, type), (
             f'{repr(exception_cls)} not type.')
 
         raise exception_cls(
-            f'{hint_label} {repr(hint)} is PEP-noncompliant (e.g., ' +
+            f'{exception_prefix}type hint {repr(hint)} '
+            f'is PEP-noncompliant (e.g., ' +
             (
                 (
                     'isinstanceable class, forward reference, or tuple of '
@@ -111,9 +113,9 @@ def die_unless_hint_nonpep(
     hint: object,
 
     # Optional parameters.
-    hint_label: str = 'Type hint',
     is_str_valid: bool = True,
-    exception_cls: Type[Exception] = BeartypeDecorHintNonPepException,
+    exception_cls: TypeException = BeartypeDecorHintNonpepException,
+    exception_prefix: str = '',
 ) -> None:
     '''
     Raise an exception unless the passed object is a **PEP-noncompliant type
@@ -127,10 +129,7 @@ def die_unless_hint_nonpep(
     ----------
     hint : object
         Object to be validated.
-    hint_label : Optional[str]
-        Human-readable label prefixing this object's representation in the
-        exception message raised by this function. Defaults to ``Type hint``.
-    is_str_valid : Optional[bool]
+    is_str_valid : bool, optional
         ``True`` only if this function permits this object to either be a
         string or contain strings. Defaults to ``True``. If this boolean is:
 
@@ -138,9 +137,12 @@ def die_unless_hint_nonpep(
           or tuple of classes and/or classnames.
         * ``False``, this object is valid only if this object is either a class
           or tuple of classes.
-    exception_cls : Optional[type]
+    exception_cls : type[Exception], optional
         Type of the exception to be raised by this function. Defaults to
-        :class:`BeartypeDecorHintNonPepException`.
+        :class:`BeartypeDecorHintNonpepException`.
+    exception_prefix : str, optional
+        Human-readable label prefixing the representation of this object in the
+        exception message. Defaults to the empty string.
 
     Raises
     ----------
@@ -166,10 +168,6 @@ def die_unless_hint_nonpep(
         return
     # Else, this object is *NOT* a PEP-noncompliant type hint. In this case,
     # subsequent logic raises an exception specific to the passed parameters.
-    #
-    # Note that the prior call has already validated "is_str_valid".
-    assert isinstance(hint_label, str), f'{repr(hint_label)} not string.'
-    assert isinstance(exception_cls, type), f'{repr(exception_cls)} not type.'
 
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # BEGIN: Synchronize changes here with the is_hint_nonpep() tester below.
@@ -180,7 +178,7 @@ def die_unless_hint_nonpep(
         # If this class is *NOT* PEP-noncompliant, raise an exception.
         die_unless_hint_nonpep_type(
             hint=hint,
-            hint_label=hint_label,
+            exception_prefix=exception_prefix,
             exception_cls=exception_cls,
         )
 
@@ -193,7 +191,7 @@ def die_unless_hint_nonpep(
     elif isinstance(hint, tuple):
         die_unless_hint_nonpep_tuple(
             hint=hint,
-            hint_label=hint_label,
+            exception_prefix=exception_prefix,
             is_str_valid=is_str_valid,
             exception_cls=exception_cls,
         )
@@ -202,8 +200,13 @@ def die_unless_hint_nonpep(
     #
     # If forward references are supported, raise an exception noting that.
     elif is_str_valid:
+        assert isinstance(exception_cls, type), (
+            f'{repr(exception_cls)} not type.')
+        assert isinstance(exception_prefix, str), (
+            f'{repr(exception_prefix)} not string.')
+
         raise exception_cls(
-            f'{hint_label} {repr(hint)} '
+            f'{exception_prefix}type hint {repr(hint)} '
             f'neither PEP-compliant nor -noncompliant '
             f'(e.g., isinstanceable class, forward reference, or '
             f'tuple of isinstanceable classes and forward references).'
@@ -212,7 +215,7 @@ def die_unless_hint_nonpep(
     # exception noting that.
     else:
         raise exception_cls(
-            f'{hint_label} {repr(hint)} '
+            f'{exception_prefix}type hint {repr(hint)} '
             f'neither PEP-compliant nor -noncompliant '
             f'(e.g., isinstanceable class or tuple of isinstanceable classes).'
         )
@@ -224,8 +227,8 @@ def die_unless_hint_nonpep_type(
     hint: type,
 
     # Optional parameters.
-    hint_label: str = 'Type hint',
-    exception_cls: Type[Exception] = BeartypeDecorHintNonPepException,
+    exception_cls: TypeException = BeartypeDecorHintNonpepException,
+    exception_prefix: str = '',
 ) -> None:
     '''
     Raise an exception unless the passed object is an **isinstanceable type**
@@ -240,12 +243,12 @@ def die_unless_hint_nonpep_type(
     ----------
     hint : type
         Object to be validated.
-    hint_label : Optional[str]
-        Human-readable label prefixing this object's representation in the
-        exception message raised by this function. Defaults to ``Type hint``.
     exception_cls : Optional[type]
         Type of the exception to be raised by this function. Defaults to
-        :class:`BeartypeDecorHintNonPepException`.
+        :class:`BeartypeDecorHintNonpepException`.
+    exception_prefix : str, optional
+        Human-readable label prefixing the representation of this object in the
+        exception message. Defaults to the empty string.
 
     Raises
     ----------
@@ -261,17 +264,25 @@ def die_unless_hint_nonpep_type(
 
     # If this object is a PEP-compliant type hint, raise an exception.
     die_if_hint_pep(
-        hint=hint, hint_label=hint_label, exception_cls=exception_cls)
+        hint=hint,
+        exception_cls=exception_cls,
+        exception_prefix=exception_prefix,
+    )
     # Else, this object is *NOT* a PEP-noncompliant type hint.
     #
     # If this object is *NOT* an isinstanceable class, raise an exception. Note
     # that this validation is typically slower than the prior validation and
     # thus intentionally performed last.
     die_unless_type_isinstanceable(
-        cls=hint, cls_label=hint_label, exception_cls=exception_cls)
+        cls=hint,
+        exception_cls=exception_cls,
+        exception_prefix=exception_prefix,
+    )
     # If this object is an isinstanceable class.
 
 
+#FIXME: Unit test this function with respect to tuples containing
+#non-isinstanceable classes.
 #FIXME: Optimize both this and the related _is_hint_nonpep_tuple() tester
 #defined below. The key realization here is that EAFP is *MUCH* faster in this
 #specific case than iteration. Why? Because iteration is guaranteed to
@@ -286,16 +297,19 @@ def die_unless_hint_nonpep_type(
 #  * Likewise for _is_hint_nonpep_tuple() vis-a-vis is_type_isinstanceable().
 #Fortunately, tuple unions are now sufficiently rare in the wild (i.e., in
 #real-world use cases) that this mild inefficiency probably no longer matters.
-#FIXME: Unit test this function with respect to tuples containing
-#non-isinstanceable classes.
+#FIXME: Indeed! Now that we have the die_unless_type_or_types_isinstanceable()
+#validator, this validator should reduce to efficiently calling
+#die_unless_type_or_types_isinstanceable() directly if "is_str_valid" is False.
+#die_unless_type_or_types_isinstanceable() performs the desired EAFP-style
+#isinstance() check in an optimally efficient manner.
 def die_unless_hint_nonpep_tuple(
     # Mandatory parameters.
     hint: object,
 
     # Optional parameters.
-    hint_label: str = 'Type hint',
     is_str_valid: bool = False,
-    exception_cls: Type[Exception] = BeartypeDecorHintNonPepException,
+    exception_cls: TypeException = BeartypeDecorHintNonpepException,
+    exception_prefix: str = '',
 ) -> None:
     '''
     Raise an exception unless the passed object is a **PEP-noncompliant tuple**
@@ -309,9 +323,6 @@ def die_unless_hint_nonpep_tuple(
     ----------
     hint : object
         Object to be validated.
-    hint_label : str, optional
-        Human-readable label prefixing this object's representation in the
-        exception message raised by this function. Defaults to ``Type hint``.
     is_str_valid : bool, optional
         ``True`` only if this function permits this tuple to contain strings.
         Defaults to ``False``. If:
@@ -321,7 +332,10 @@ def die_unless_hint_nonpep_tuple(
         * ``False``, this tuple is valid only when containing classes.
     exception_cls : type, optional
         Type of the exception to be raised by this function. Defaults to
-        :class:`BeartypeDecorHintNonPepException`.
+        :class:`BeartypeDecorHintNonpepException`.
+    exception_prefix : str, optional
+        Human-readable label prefixing the representation of this object in the
+        exception message. Defaults to the empty string.
 
     Raises
     ----------
@@ -351,8 +365,9 @@ def die_unless_hint_nonpep_tuple(
     # raises an exception specific to the passed parameters.
     #
     # Note that the prior call has already validated "is_str_valid".
-    assert isinstance(hint_label, str), f'{repr(hint_label)} not string.'
     assert isinstance(exception_cls, type), f'{repr(exception_cls)} not type.'
+    assert isinstance(exception_prefix, str), (
+        f'{repr(exception_prefix)} not string.')
 
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # BEGIN: Synchronize changes here with the _is_hint_nonpep_tuple() tester.
@@ -360,12 +375,13 @@ def die_unless_hint_nonpep_tuple(
 
     # If this object is *NOT* a tuple, raise an exception.
     if not isinstance(hint, tuple):
-        raise exception_cls(f'{hint_label} {repr(hint)} not tuple.')
+        raise exception_cls(
+            f'{exception_prefix}type hint {repr(hint)} not tuple.')
     # Else, this object is a tuple.
     #
     # If this tuple is empty, raise an exception.
     elif not hint:
-        raise exception_cls(f'{hint_label} tuple empty.')
+        raise exception_cls(f'{exception_prefix}tuple type hint empty.')
     # Else, this tuple is non-empty.
 
     # For each item of this tuple...
@@ -379,7 +395,7 @@ def die_unless_hint_nonpep_tuple(
             # If this class is *NOT* PEP-noncompliant, raise an exception.
             die_unless_hint_nonpep_type(
                 hint=hint_item,
-                hint_label=hint_label,
+                exception_prefix=exception_prefix,
                 exception_cls=exception_cls,
             )
         # Else, this item is *NOT* a class.
@@ -389,7 +405,7 @@ def die_unless_hint_nonpep_tuple(
             # If forward references are unsupported, raise an exception.
             if not is_str_valid:
                 raise exception_cls(
-                    f'{hint_label} {repr(hint)} '
+                    f'{exception_prefix}tuple type hint {repr(hint)} '
                     f'forward reference "{hint_item}" unsupported.'
                 )
             # Else, silently accept this item.
@@ -399,7 +415,8 @@ def die_unless_hint_nonpep_tuple(
         # forward references are permitted or not.
         else:
             raise exception_cls(
-                f'{hint_label} {repr(hint)} item {repr(hint_item)} '
+                f'{exception_prefix}tuple type hint {repr(hint)} '
+                f'item {repr(hint_item)} invalid '
                 f'{"neither type nor string" if is_str_valid else "not type"}.'
             )
 
@@ -409,7 +426,7 @@ def is_hint_nonpep(
     hint: object,
 
     # Optional parameters.
-    is_str_valid: bool = True,
+    is_str_valid: bool = False,
 ) -> bool:
     '''
     ``True`` only if the passed object is a **PEP-noncompliant type hint**
@@ -424,9 +441,9 @@ def is_hint_nonpep(
     ----------
     hint : object
         Object to be inspected.
-    is_str_valid : Optional[bool]
+    is_str_valid : bool, optional
         ``True`` only if this function permits this object to be a string.
-        Defaults to ``True``. If this boolean is:
+        Defaults to ``False``. If this boolean is:
 
         * ``True``, this object is valid only if this object is either a class
           or tuple of classes and/or classnames.
@@ -480,7 +497,7 @@ def _is_hint_nonpep_tuple(
     hint: object,
 
     # Optional parameters.
-    is_str_valid: bool = True,
+    is_str_valid: bool = False,
 ) -> bool:
     '''
     ``True`` only if the passed object is a PEP-noncompliant non-empty tuple of
@@ -492,9 +509,9 @@ def _is_hint_nonpep_tuple(
     ----------
     hint : object
         Object to be inspected.
-    is_str_valid : Optional[bool]
+    is_str_valid : bool, optional
         ``True`` only if this function permits this tuple to contain strings.
-        Defaults to ``True``. If this boolean is:
+        Defaults to ``False``. If this boolean is:
 
         * ``True``, this tuple is valid only when containing classes and/or
           classnames.
