@@ -18,7 +18,7 @@ from beartype.roar import (
     BeartypeDecorHintPepException,
     BeartypeDecorHintPepSignException,
 )
-from beartype._util.cache.utilcachecall import callable_cached
+from beartype._cave._cavefast import HintGenericSubscriptedType
 from beartype._data.hint.pep.datapeprepr import (
     HINT_REPR_PREFIX_ARGS_0_OR_MORE_TO_SIGN,
     HINT_REPR_PREFIX_ARGS_1_OR_MORE_TO_SIGN,
@@ -28,16 +28,16 @@ from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._data.hint.pep.sign.datapepsigns import (
     HintSignGeneric,
     HintSignNewType,
+    HintSignTypedDict,
+    HintSignTypeVar,
 )
 from beartype._data.hint.pep.sign.datapepsignset import (
-    HINT_SIGNS_TYPE_STDLIB,
-)
-from beartype._util.hint.pep.proposal.utilpep484 import (
-    get_hint_pep484_generic_bases_unerased,
-    is_hint_pep484_newtype_pre_python3_10,
+    HINT_SIGNS_ORIGIN_ISINSTANCEABLE,
 )
+from beartype._util.cache.utilcachecall import callable_cached
+from beartype._util.hint.pep.proposal.pep484.utilpep484newtype import (
+    is_hint_pep484_newtype_pre_python310)
 from beartype._util.hint.pep.proposal.utilpep585 import (
-    get_hint_pep585_generic_bases_unerased,
     get_hint_pep585_generic_typevars,
     is_hint_pep585_generic,
 )
@@ -46,19 +46,56 @@ from beartype._util.py.utilpyversion import (
     IS_PYTHON_AT_LEAST_3_9,
     IS_PYTHON_AT_LEAST_3_7,
 )
-from typing import Any, Optional, Tuple
+from beartype._util.utiltyping import TupleTypes
+from typing import Any, Optional
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
 
 # ....................{ GETTERS ~ args                    }....................
-# If the active Python interpreter targets at least Python >= 3.7, implement
-# this function to access the standard "__args__" dunder instance variable.
-if IS_PYTHON_AT_LEAST_3_7:
+# If the active Python interpreter targets Python >= 3.9, implement this
+# getter to directly access the "__args__" dunder attribute.
+if IS_PYTHON_AT_LEAST_3_9:
+    _HINT_PEP585_ARGS_EMPTY_TUPLE = ((),)
+    '''
+    Tuple containing only the empty tuple, to be returned from the
+    :func:`get_hint_pep_args` getter when passed a :pep:`585`-compliant type
+    hint subscripted by the empty tuple (e.g., ``tuple[()]``).
+    '''
+
+
     def get_hint_pep_args(hint: object) -> tuple:
 
-        # Return the value of the "__args__" dunder attribute on this object if
-        # this object defines this attribute *OR* the empty tuple otherwise.
+        # Return the value of the "__args__" dunder attribute if this hint
+        # defines this attribute *OR* the empty tuple otherwise.
+        hint_args = getattr(hint, '__args__', ())
+
+        # Return either...
+        return (
+            # If this hint appears to be unsubscripted but is PEP
+            # 585-compliant, then this hint *WAS* actually subscripted by the
+            # empty tuple (e.g., "tuple[()]"). For unknown reasons, the
+            # "HintGenericSubscriptedType" superclass erroneously reduces the
+            # empty tuple subscripting such hints to... literally nothing.
+            # Since doing so violates orthogonality with equivalent PEP
+            # 484-compliant type hints that do correctly preserve their
+            # arguments (e.g., "Tuple[()]"), we silently coerce PEP
+            # 585-compliant type hints to behave like PEP 484-compliant type
+            # hints by returning a tuple containing only the empty tuple.
+            _HINT_PEP585_ARGS_EMPTY_TUPLE
+            if (
+                not hint_args and isinstance(hint, HintGenericSubscriptedType)
+            ) else
+            # Else, return this tuple as is.
+            hint_args
+        )
+# Else if the active Python interpreter targets Python >= 3.7, implement this
+# getter to directly access the "__args__" dunder attribute.
+elif IS_PYTHON_AT_LEAST_3_7:
+    def get_hint_pep_args(hint: object) -> tuple:
+
+        # Return the value of the "__args__" dunder attribute if this hint
+        # defines this attribute *OR* the empty tuple otherwise.
         return getattr(hint, '__args__', ())
 #FIXME: Drop this like hot lead after dropping Python 3.6 support.
 # Else, the active Python interpreter targets Python 3.6. In this case...
@@ -67,33 +104,26 @@ if IS_PYTHON_AT_LEAST_3_7:
 else:
     def get_hint_pep_args(hint: object) -> tuple:
 
-        # Avoid circular import dependencies.
-        from beartype._util.hint.pep.utilpeptest import is_hint_pep_typevar
-
         # If this hint is a poorly designed Python 3.6-specific "type alias",
         # this hint is a subscription of either the "typing.Match" or
         # "typing.Pattern" objects. In this case, this hint declares a
         # non-standard "type_var" instance variable whose value is either
-        # "typing.AnyStr", "str", or "bytes". Since only the former is an
-        # actual type variable, however, we further test that condition.
+        # "typing.AnyStr", "str", or "bytes". Create and return a new 1-tuple
+        # containing only the value of this variable.
         if isinstance(hint, typing._TypeAlias):  # type: ignore[attr-defined]
-            # If this value is a type variable, return the empty tuple.
-            if is_hint_pep_typevar(hint.type_var):
-                return ()
-            # Else, this value is either the builtin "str" or "bytes" class. In
-            # either case, return a new 1-tuple containing only this class.
-            else:
-                return (hint.type_var,)
+            return (hint.type_var,)
 
-        # Else, this hint is a poorly designed Python 3.6-specific "generic
-        # meta." In this case, this hint declares the standard
-        # "__parameters__" dunder instance variable in a non-standard way.
-        # Specifically, the trailing "or ()" test below is needed to handle
-        # undocumented edge cases under the Python 3.6-specific implementation
-        # of the "typing" module:
-        #       >>> import typing as t
-        #       >>> t.Tuple.__args__   # yes, this is total bullocks
-        #       None
+        # Return the value of the "__args__" dunder attribute if this hint
+        # defines this attribute *OR* the empty tuple otherwise.
+        #
+        # Note this hint is a poorly designed Python 3.6-specific "generic
+        # meta." In this case, this hint declares the standard "__args__"
+        # dunder attribute in a non-standard way. Specifically, the trailing
+        # "or ()" test below is needed to handle undocumented edge cases under
+        # the Python 3.6-specific "typing" implementation:
+        #     >>> import typing as t
+        #     >>> t.Tuple.__args__   # yes, this is total bullocks
+        #     None
         return getattr(hint, '__args__', ()) or ()
 
 # Document this function regardless of implementation details above.
@@ -108,7 +138,7 @@ get_hint_pep_args.__doc__ = '''
 
     Caveats
     ----------
-    **This function should always be called in lieu of attempting to directly
+    **This getter should always be called in lieu of attempting to directly
     access the low-level** ``__args__`` **dunder attribute.** Various
     singleton objects defined by the :mod:`typing` module (e.g.,
     :attr:`typing.Any`, :attr:`typing.NoReturn`) fail to define this attribute,
@@ -116,17 +146,30 @@ get_hint_pep_args.__doc__ = '''
     logic attempting to directly access this attribute. Thus this function,
     which "fills in the gaps" by implementing this oversight.
 
+    **This getter never lies, unlike the comparable**
+    :func:`get_hint_pep_typevars` **getter.** Whereas
+    :func:`get_hint_pep_typevars` synthetically propagates type variables from
+    child to parent type hints (rather than preserving the literal type
+    variables subscripting this type hint), this getter preserves the literal
+    arguments subscripting this type hint if any. Notable cases where the two
+    differ include:
+
+    * Generic classes subclassing pseudo-superclasses subscripted by one or
+      more type variables (e.g., ``class MuhGeneric(Generic[S, T])``).
+    * Unions subscripted by one or more child type hints subscripted by one or
+      more type variables (e.g., ``Union[str, Iterable[Tuple[S, T]]]``).
+
     Parameters
     ----------
     hint : object
-        Object to be inspected.
+        PEP-compliant type hint to be inspected.
 
     Returns
     ----------
     tuple
         Either:
 
-        * If this object defines an ``__args__`` dunder attribute, the value of
+        * If this hint defines an ``__args__`` dunder attribute, the value of
           that attribute.
         * Else, the empty tuple.
 
@@ -137,15 +180,17 @@ get_hint_pep_args.__doc__ = '''
         ...     get_hint_pep_args)
         >>> get_hint_pep_args(typing.Any)
         ()
-        >>> get_hint_pep_args(typing.List[int, str, typing.Dict[str, str])
+        >>> get_hint_pep_args(typing.List[int, str, typing.Dict[str, str]])
         (int, str, typing.Dict[str, str])
     '''
 
 # ....................{ GETTERS ~ typevars                }....................
-# If the active Python interpreter targets at least Python >= 3.9, implement
-# this function to perform cray-cray logic. *sigh*
+# If the active Python interpreter targets Python >= 3.9, implement this
+# function to either directly access the "__parameters__" dunder attribute for
+# type hints that are not PEP 585-compliant generics *OR* to synthetically
+# reconstruct that attribute for PEP 585-compliant generics. *sigh*
 if IS_PYTHON_AT_LEAST_3_9:
-    def get_hint_pep_typevars(hint: object) -> Tuple[type, ...]:
+    def get_hint_pep_typevars(hint: object) -> TupleTypes:
 
         # Value of the "__parameters__" dunder attribute on this object if this
         # object defines this attribute *OR* "None" otherwise.
@@ -166,11 +211,10 @@ if IS_PYTHON_AT_LEAST_3_9:
 
         # Return this attribute.
         return hint_pep_typevars
-
-# Else if the active Python interpreter targets Python 3.7 or 3.8, implement
-# this function to access the "__parameters__" dunder instance variable.
+# Else if the active Python interpreter targets Python >= 3.7, implement
+# this function to directly access the "__parameters__" dunder attribute.
 elif IS_PYTHON_AT_LEAST_3_7:
-    def get_hint_pep_typevars(hint: object) -> Tuple[type, ...]:
+    def get_hint_pep_typevars(hint: object) -> TupleTypes:
 
         # Value of the "__parameters__" dunder attribute on this object if this
         # object defines this attribute *OR* the empty tuple otherwise. Note:
@@ -188,10 +232,7 @@ elif IS_PYTHON_AT_LEAST_3_7:
 #
 # Gods... this is horrible. Thanks for nuthin', Python 3.6.
 else:
-    def get_hint_pep_typevars(hint: object) -> Tuple[type, ...]:
-
-        # Avoid circular import dependencies.
-        from beartype._util.hint.pep.utilpeptest import is_hint_pep_typevar
+    def get_hint_pep_typevars(hint: object) -> TupleTypes:
 
         # If this hint is a poorly designed Python 3.6-specific "type alias",
         # this hint is a subscription of either the "typing.Match" or
@@ -200,9 +241,12 @@ else:
         # "typing.AnyStr", "str", or "bytes". Since only the former is an
         # actual type variable, however, we further test that condition.
         if isinstance(hint, typing._TypeAlias):  # type: ignore[attr-defined]
+            # Sign uniquely identifying this hint if any *OR* "None" otherwise.
+            hint_sign = get_hint_pep_sign_or_none(hint.type_var)
+
             # If this value is a type variable, return a new 1-tuple containing
             # only this type variable.
-            if is_hint_pep_typevar(hint.type_var):
+            if hint_sign is HintSignTypeVar:
                 return (hint.type_var,)
             # Else, this value is *NOT* a type variable. In this case, return
             # the empty tuple.
@@ -301,6 +345,8 @@ def get_hint_pep_sign(hint: Any) -> HintSign:
 
     See Also
     ----------
+    :func:`get_hint_pep_sign_or_none`
+        Further details.
     '''
 
     # Sign uniquely identifying this hint if recognized *OR* "None" otherwise.
@@ -341,10 +387,6 @@ def get_hint_pep_sign(hint: Any) -> HintSign:
 #* Remove all now-unused "beartype._util.hint.pep.*" testers. Thanks to this
 #  dramatically simpler approach, we no longer require the excessive glut of
 #  PEP-specific testers we previously required.
-#* Merge the contents of all now minimal
-#  "beartype._data.hint.pep.proposal.*" submodules into their parent
-#  "beartype._util.hint.pep.proposal.*" submodules. There's no longer any
-#  demonstrable benefit to separating the two, so please cease doing so.
 @callable_cached
 def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     '''
@@ -386,7 +428,7 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
       representation** (i.e., the non-human-readable string returned by the
       :func:`repr` builtin).
 
-    This getter function is memoized for efficiency.
+    This getter is memoized for efficiency.
 
     Motivation
     ----------
@@ -434,10 +476,6 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
         typing.Iterable
     '''
 
-    # ..................{ IMPORTS                           }..................
-    # Avoid circular import dependencies.
-    from beartype._util.hint.pep.utilpeptest import is_hint_pep_generic
-
     # For efficiency, this tester identifies the sign of this type hint with
     # multiple phases performed in ascending order of average time complexity.
     #
@@ -471,7 +509,10 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     # Class of this hint.
     hint_type = hint.__class__
 
-    # Fully-qualified name of this class.
+    #FIXME: Is this actually the case? Do non-physical classes dynamically
+    #defined at runtime actually define these dunder attributes as well?
+    # Fully-qualified name of this class. Note that *ALL* classes are
+    # guaranteed to define the dunder attributes accessed here.
     hint_type_name = f'{hint_type.__module__}.{hint_type.__qualname__}'
 
     # Sign identifying this hint if this hint is identifiable by its classname
@@ -539,11 +580,14 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     # For minor efficiency gains, the following tests are intentionally ordered
     # in descending likelihood of a match.
 
+    # Avoid circular import dependencies.
+    from beartype._util.hint.pep.proposal.pep484585.utilpep484585generic import (
+        is_hint_pep484585_generic)
+    from beartype._util.hint.pep.proposal.utilpep589 import is_hint_pep589
+
     # If this hint is a PEP 484- or 585-compliant generic (i.e., user-defined
     # class superficially subclassing at least one PEP 484- or 585-compliant
-    # type hint), return that sign
-    #
-    # However, note that:
+    # type hint), return that sign. However, note that:
     # * Generics *CANNOT* be detected by the general-purpose logic performed
     #   above, as the "typing.Generic" ABC does *NOT* define a __repr__()
     #   dunder method returning a string prefixed by the "typing." substring.
@@ -561,14 +605,27 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     # * *NO* PEP 585-compliant generics subclass this ABC unless those generics
     #   are also either PEP 484- or 544-compliant. Indeed, PEP 585-compliant
     #   generics subclass *NO* common superclass.
+    # * Generics are *NOT* necessarily classes, despite originally being
+    #   declared as classes. Although *MOST* generics are classes, some are
+    #   shockingly *NOT*: e.g.,
+    #       >>> from typing import Generic, TypeVar
+    #       >>> S = TypeVar('S')
+    #       >>> T = TypeVar('T')
+    #       >>> class MuhGeneric(Generic[S, T]): pass
+    #       >>> non_class_generic = MuhGeneric[S, T]
+    #       >>> isinstance(non_class_generic, type)
+    #       False
     #
     # Ergo, the "typing.Generic" ABC uniquely identifies many but *NOT* all
-    # generics. While non-ideal, the failure of PEP 585-compliant generics to
-    # subclass a common superclass leaves us with little alternative.
-    if is_hint_pep_generic(hint):
+    # generics. While non-ideal, the failure of PEP 585-compliant generics
+    # to subclass a common superclass leaves us with little alternative.
+    if is_hint_pep484585_generic(hint):
         return HintSignGeneric
     # Else, this hint is *NOT* a PEP 484- or 585-compliant generic.
     #
+    # If this hint is a PEP 589-compliant typed dictionary, return that sign.
+    elif is_hint_pep589(hint):
+        return HintSignTypedDict
     # If the active Python interpreter targets Python < 3.10 (and thus defines
     # PEP 484-compliant "NewType" type hints as closures returned by that
     # function that are sufficiently dissimilar from all other type hints to
@@ -577,384 +634,24 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     #
     # Note that these hints *CANNOT* be detected by the general-purpose logic
     # performed above, as the __repr__() dunder methods of the closures created
-    # and returned by the NewType() closure factory function returns a standard
-    # representation rather than string prefixed by "typing.": e.g.,
+    # and returned by the NewType() closure factory function return a standard
+    # representation rather than a string prefixed by "typing.": e.g.,
     #     >>> import typing as t
     #     >>> repr(t.NewType('FakeStr', str))
     #     '<function NewType.<locals>.new_type at 0x7fca39388050>'
-    elif IS_PYTHON_AT_MOST_3_9 and is_hint_pep484_newtype_pre_python3_10(hint):
+    elif IS_PYTHON_AT_MOST_3_9 and is_hint_pep484_newtype_pre_python310(hint):
         return HintSignNewType
 
     # ..................{ ERROR                             }..................
     # Else, this hint is unrecognized. In this case, return "None".
     return None
 
-# ....................{ GETTERS ~ type : generic          }....................
-@callable_cached
-def get_hint_pep_generic_type_or_none(hint: Any) -> Optional[type]:
-    '''
-    Either the passed **generic** (i.e., class superficially subclassing at
-    least one PEP-compliant type hint that is possibly *not* an actual class)
-    if **unsubscripted** (i.e., indexed by *no* arguments or type variables),
-    the unsubscripted generic underlying this generic if **subscripted** (i.e.,
-    indexed by one or more arguments and/or type variables), *or* ``None``
-    otherwise (i.e., if this hint is *not* a generic).
-
-    Specifically, this getter returns:
-
-    * If this hint both originates from an **origin type** (i.e.,
-      non-:mod:`typing` class such that *all* objects satisfying this hint are
-      instances of that class), that origin type.
-    * Else if this hint is already a class, this hint as is.
-    * Else, ``None``.
-
-    This getter is memoized for efficiency.
-
-    Caveats
-    ----------
-    **This getter returns false positives in edge cases.** That is, this getter
-    returns non-``None`` values for both generics and non-generics. Callers
-    *must* perform subsequent tests to distinguish these two cases.
-
-    Parameters
-    ----------
-    hint : object
-        Object to be inspected.
-
-    Returns
-    ----------
-    Optional[type]
-        Either:
-
-        * If this hint is a generic, the class originating this generic.
-        * Else, ``None``.
-
-    See Also
-    ----------
-    :func:`_get_hint_pep_origin_object_or_none`
-        Further details.
-    '''
-
-    # Arbitrary object originating this hint if any *OR* "None" otherwise.
-    hint_origin = _get_hint_pep_origin_object_or_none(hint)
-    # print(f'{repr(hint)} hint_origin: {repr(hint_origin)}')
-
-    # If this object is a class, this object is the origin type originating
-    # this hint. In this case, return this object.
-    if isinstance(hint_origin, type):
-        return hint_origin
-    # Else if this hint is already a class, this class is effectively already
-    # its origin type. In this case, return this class as is.
-    elif isinstance(hint, type):
-        return hint
-    # Else, this hint is *NOT* a class. In this case, this hint originates from
-    # *NO* origin type.
-    else:
-        return None
-
-# ....................{ GETTERS ~ type : stdlib           }....................
-def get_hint_pep_type_stdlib(hint: object) -> type:
-    '''
-    **Standard origin type** (i.e., isinstanceable class declared by Python's
-    standard library such that *all* objects satisfying the passed
-    PEP-compliant type hint are instances of this class) originating this hint
-    if this hint originates from such a type *or* raise an exception otherwise
-    (i.e., if this hint does *not* originate from such a type).
-
-    This getter is intentionally *not* memoized (e.g., by the
-    :func:`callable_cached` decorator), as the implementation trivially reduces
-    to an efficient one-liner.
-
-    Parameters
-    ----------
-    hint : object
-        Object to be inspected.
-
-    Returns
-    ----------
-    type
-        Standard origin type originating this hint.
-
-    Raises
-    ----------
-    BeartypeDecorHintPepException
-        If this hint does *not* originate from a standard origin type.
-
-    See Also
-    ----------
-    :func:`get_hint_pep_type_stdlib_or_none`
-        Related getter.
-    '''
-
-    # Origin type originating this object if any *OR* "None" otherwise.
-    hint_type_stdlib = get_hint_pep_type_stdlib_or_none(hint)
-
-    # If this type does *NOT* exist, raise an exception.
-    if hint_type_stdlib is None:
-        raise BeartypeDecorHintPepException(
-            f'Type hint {repr(hint)} not originative '
-            f'(i.e., does not originate from isinstanceable class declared by '
-            f"Python's standard library)."
-        )
-    # Else, this type exists.
-
-    # Return this type.
-    return hint_type_stdlib
-
-
-def get_hint_pep_type_stdlib_or_none(hint: Any) -> Optional[type]:
-    '''
-    **Standard origin type** (i.e., isinstanceable class declared by Python's
-    standard library such that *all* objects satisfying the passed
-    PEP-compliant type hint are instances of this class) originating this hint
-    if this hint originates from such a type *or* ``None`` otherwise (i.e., if
-    this hint does *not* originate from such a type).
-
-    This getter is intentionally *not* memoized (e.g., by the
-    :func:`callable_cached` decorator), as the implementation trivially reduces
-    to an efficient one-liner.
-
-    Caveats
-    ----------
-    **This high-level getter should always be called in lieu of the low-level**
-    :func:`_get_hint_pep_origin_object_or_none` **getter or attempting to
-    directly access the low-level** ``__origin__`` **dunder attribute.**
-
-    Parameters
-    ----------
-    hint : object
-        Object to be inspected.
-
-    Returns
-    ----------
-    Optional[type]
-        Either:
-
-        * If this hint originates from a standard origin type, that type.
-        * Else, ``None``.
-
-    See Also
-    ----------
-    :func:`get_hint_pep_type_stdlib`
-        Related getter.
-    :func:`_get_hint_pep_origin_object_or_none`
-        Further details.
-    '''
-
-    # Sign uniquely identifying this hint.
-    hint_sign = get_hint_pep_sign(hint)
-
-    # Return either...
-    return (
-        # If this sign originates from an origin type, that type.
-        _get_hint_pep_origin_object_or_none(hint)
-        if hint_sign in HINT_SIGNS_TYPE_STDLIB else
-        # Else, "None".
-        None
-    )
-
-# ....................{ GETTERS ~ kind : generic          }....................
-def get_hint_pep_generic_bases_unerased(hint: object) -> Tuple[object, ...]:
-    '''
-    Tuple of all **unerased pseudo-superclasses** (i.e., PEP-compliant objects
-    originally listed as superclasses prior to their implicit type erasure
-    under :pep:`560`) of the passed PEP-compliant **generic** (i.e., class
-    superficially subclassing at least one non-class PEP-compliant object) if
-    this object is a generic *or* raise an exception otherwise (i.e., if this
-    object is either not a class *or* is a class subclassing no non-class
-    PEP-compliant objects).
-
-    This getter is intentionally *not* memoized (e.g., by the
-    :func:`callable_cached` decorator), as the implementation trivially reduces
-    to an efficient one-liner.
-
-    Caveats
-    ----------
-    **This function should always be called in lieu of attempting to directly
-    access the low-level** ``__orig_bases__`` **dunder instance variable.**
-    Most PEP-compliant type hints fail to declare that variable, guaranteeing
-    :class:`AttributeError` exceptions from all general-purpose logic
-    attempting to directly access that variable. Thus this function, which
-    "fills in the gaps" by implementing this oversight.
-
-    **This function returns tuples possibly containing a mixture of actual
-    superclasses and pseudo-superclasses superficially masquerading as actual
-    superclasses subscripted by one or more PEP-compliant child hints,**
-    including type variables (e.g., ``(typing.Iterable[T], typing.Sized[T])``).
-    In particular, most public attributes of the :mod:`typing` module used as
-    superclasses are *not* actually types but singleton objects devilishly
-    masquerading as types. Most actual :mod:`typing` superclasses are private,
-    fragile, and prone to alteration or even removal between Python versions.
-
-    Motivation
-    ----------
-    :pep:`560` (i.e., "Core support for typing module and generic types)
-    formalizes the ``__orig_bases__`` dunder attribute first informally
-    introduced by the :mod:`typing` module's implementation of :pep:`484`.
-    Naturally, :pep:`560` remains as unusable as :pep:`484` itself. Ideally,
-    :pep:`560` would have generalized the core intention of preserving each
-    original user-specified subclass tuple of superclasses as a full-blown
-    ``__orig_mro__`` dunder attribute listing the original method resolution
-    order (MRO) of that subclass had that tuple *not* been modified.
-
-    Naturally, :pep:`560` did no such thing. The original MRO remains
-    obfuscated and effectively inaccessible. While computing that MRO would
-    technically be feasible, doing so would also be highly non-trivial,
-    expensive, and fragile. Instead, this function retrieves *only* the tuple
-    of :mod:`typing`-specific pseudo-superclasses that this object's class
-    originally attempted (but failed) to subclass.
-
-    You are probably now agitatedly cogitating to yourself in the darkness:
-    "But @leycec: what do you mean :pep:`560`? Wasn't :pep:`560` released
-    *after* :pep:`484`? Surely no public API defined by the Python stdlib would
-    be so malicious as to silently alter the tuple of base classes listed by a
-    user-defined subclass?"
-
-    As we've established both above and elsewhere throughout the codebase,
-    everything developed for `PEP 484` -- including :pep:`560`, which derives
-    its entire raison d'etre from :pep:`484` -- are fundamentally insane. In
-    this case, :pep:`484` is insane by subjecting parametrized :mod:`typing`
-    types employed as base classes to "type erasure," because:
-
-         ...it is common practice in languages with generics (e.g. Java,
-         TypeScript).
-
-    Since Java and TypeScript are both terrible languages, blindly
-    recapitulating bad mistakes baked into such languages is an equally bad
-    mistake. In this case, "type erasure" means that the :mod:`typing` module
-    *intentionally* destroys runtime type information for nebulous and largely
-    unjustifiable reasons (i.e., Big Daddy Java and TypeScript do it, so it
-    must be unquestionably good).
-
-    Specifically, the :mod:`typing` module intentionally munges :mod:`typing`
-    types listed as base classes in user-defined subclasses as follows:
-
-    * All base classes whose origin is a builtin container (e.g.,
-      ``typing.List[T]``) are reduced to that container (e.g.,
-      :class:`list`).
-    * All base classes derived from an abstract base class declared by the
-      :mod:`collections.abc` subpackage (e.g., ``typing.Iterable[T]``) are
-      reduced to that abstract base class (e.g.,
-      ``collections.abc.Iterable``).
-    * All surviving base classes that are parametrized (e.g.,
-      ``typing.Generic[S, T]``) are stripped of that parametrization (e.g.,
-      :class:`typing.Generic`).
-
-    Since there exists no counterpart to the :class:`typing.Generic`
-    superclass, the :mod:`typing` module preserves that superclass in
-    unparametrized form. Naturally, this is useless, as an unparametrized
-    :class:`typing.Generic` superclass conveys no meaningful type information.
-    All other superclasses are reduced to their non-:mod:`typing`
-    counterparts: e.g.,
-
-        .. code-block:: python
-
-        >>> from typing import TypeVar, Generic, Iterable, List
-        >>> T = TypeVar('T')
-        >>> class UserDefinedGeneric(List[T], Iterable[T], Generic[T]): pass
-        # This is type erasure.
-        >>> UserDefinedGeneric.__mro__
-        (list, collections.abc.Iterable, Generic)
-        # This is type preservation -- except the original MRO is discarded.
-        # So, it's not preservation; it's reduction! We take what we can get.
-        >>> UserDefinedGeneric.__orig_bases__
-        (typing.List[T], typing.Iterable[T], typing.Generic[T])
-        # Guess which we prefer?
-
-    So, we prefer the generally useful ``__orig_bases__`` dunder tuple over
-    the generally useless ``__mro__`` dunder tuple. Note, however, that the
-    latter *is* still occasionally useful and thus occasionally returned by
-    this getter. For inexplicable reasons, **single-inherited protocols**
-    (i.e., classes directly subclassing *only* the :pep:`544`-compliant
-    :attr:`typing.Protocol` abstract base class (ABC)) are *not* subject to
-    type erasure and thus constitute a notable exception to this heuristic:
-
-        .. code-block:: python
-
-        >>> from typing import Protocol
-        >>> class UserDefinedProtocol(Protocol): pass
-        >>> UserDefinedProtocol.__mro__
-        (__main__.UserDefinedProtocol, typing.Protocol, typing.Generic, object)
-        >>> UserDefinedProtocol.__orig_bases__
-        AttributeError: type object 'UserDefinedProtocol' has no attribute
-        '__orig_bases__'
-
-    Welcome to :mod:`typing` hell, where even :mod:`typing` types lie broken
-    and misshapen on the killing floor of overzealous theory-crafting purists.
-
-    Parameters
-    ----------
-    hint : object
-        Object to be inspected.
-
-    Returns
-    ----------
-    Tuple[object]
-        Tuple of the one or more unerased pseudo-superclasses of this
-        PEP-compliant generic.
-
-    Raises
-    ----------
-    BeartypeDecorHintPepException
-        If this hint is either:
-
-        * *Not* a PEP-compliant generic.
-        * Is a PEP-compliant generic subclassing *no* pseudo-superclasses.
-
-    Examples
-    ----------
-        >>> import typing
-        >>> from beartype._util.hint.pep.utilpepget import (
-        ...     get_hint_pep_generic_bases_unerased)
-        >>> get_hint_pep_generic_bases_unerased(
-        ...     typing.Union[str, typing.List[int]])
-        ()
-        >>> T = typing.TypeVar('T')
-        >>> class MuhIterable(typing.Iterable[T], typing.Container[T]): pass
-        >>> get_hint_pep585_generic_bases_unerased(MuhIterable)
-        (typing.Iterable[~T], typing.Container[~T])
-        >>> MuhIterable.__mro__
-        (MuhIterable,
-         collections.abc.Iterable,
-         collections.abc.Container,
-         typing.Generic,
-         object)
-    '''
-
-    # Tuple of either...
-    #
-    # Note this implicitly raises a "BeartypeDecorHintPepException" if this
-    # object is *NOT* a PEP-compliant generic. Ergo, we need not explicitly
-    # validate that above.
-    hint_pep_generic_bases_unerased = (
-        # If this is a PEP 585-compliant generic, all unerased
-        # pseudo-superclasses of this PEP 585-compliant generic.
-        get_hint_pep585_generic_bases_unerased(hint)
-        if is_hint_pep585_generic(hint) else
-        # Else, this *MUST* be a PEP 484-compliant generic. In this case, all
-        # unerased pseudo-superclasses of this PEP 484-compliant generic.
-        get_hint_pep484_generic_bases_unerased(hint)
-    )
-
-    # If this generic subclasses *NO* pseudo-superclass, raise an exception.
-    #
-    # Note this should have already been guaranteed on our behalf by:
-    # * If this generic is PEP 484-compliant, the "typing" module.
-    # * If this generic is PEP 585-compliant, CPython or PyPy itself.
-    if not hint_pep_generic_bases_unerased:
-        raise BeartypeDecorHintPepException(
-            f'PEP generic {repr(hint)} subclasses no superclasses.')
-    # Else, this generic subclasses one or more pseudo-superclasses.
-
-    # Return this tuple of these pseudo-superclasses.
-    return hint_pep_generic_bases_unerased
-
-# ....................{ PRIVATE ~ getters : type          }....................
+# ....................{ GETTERS ~ origin                  }....................
 # If the active Python interpreter targets at least Python >= 3.7, implement
 # this function to access the standard "__origin__" dunder instance variable
 # whose value is the origin type originating this hint.
 if IS_PYTHON_AT_LEAST_3_7:
-    def _get_hint_pep_origin_object_or_none(hint: Any) -> Optional[Any]:
+    def get_hint_pep_origin_or_none(hint: Any) -> Optional[Any]:
 
         # Return this hint's origin object if any *OR* "None" otherwise.
         return getattr(hint, '__origin__', None)
@@ -966,7 +663,7 @@ if IS_PYTHON_AT_LEAST_3_7:
 else:
     from beartype._util.utilobject import SENTINEL
 
-    def _get_hint_pep_origin_object_or_none(hint: Any) -> Optional[Any]:
+    def get_hint_pep_origin_or_none(hint: Any) -> Optional[Any]:
 
         # If this hint is a poorly designed Python 3.6-specific "type
         # alias", this hint is a subscription of either the "typing.Match"
@@ -1006,7 +703,7 @@ else:
         )
 
 # Document this function regardless of implementation details above.
-_get_hint_pep_origin_object_or_none.__doc__ = '''
+get_hint_pep_origin_or_none.__doc__ = '''
     **Unsafe origin object** (i.e., arbitrary object possibly related to the
     passed PEP-compliant type hint but *not* necessarily a non-:mod:`typing`
     class such that *all* objects satisfying this hint are instances of this
@@ -1019,7 +716,7 @@ _get_hint_pep_origin_object_or_none.__doc__ = '''
 
     Caveats
     ----------
-    **The high-level** :func:`get_hint_pep_type_stdlib_or_none` function should
+    **The high-level** :func:`get_hint_pep_type_isinstanceable_or_none` function should
     always be called in lieu of this low-level function.** Whereas the former
     is guaranteed to return either a class or ``None``, this function enjoys no
     such guarantees and instead returns what the caller can only safely assume
@@ -1081,3 +778,104 @@ _get_hint_pep_origin_object_or_none.__doc__ = '''
         >>> typing.Union[int, str].__origin__
         typing.Union
     '''
+
+# ....................{ GETTERS ~ origin : type           }....................
+def get_hint_pep_origin_type_isinstanceable(hint: object) -> type:
+    '''
+    **Isinstanceable origin type** (i.e., class passable as the second argument
+    to the :func:`isinstance` builtin such that *all* objects satisfying the
+    passed PEP-compliant type hint are instances of this class) originating
+    this hint if this hint originates from such a type *or* raise an exception
+    otherwise (i.e., if this hint does *not* originate from such a type).
+
+    This getter is intentionally *not* memoized (e.g., by the
+    :func:`callable_cached` decorator), as the implementation trivially reduces
+    to an efficient one-liner.
+
+    Parameters
+    ----------
+    hint : object
+        Object to be inspected.
+
+    Returns
+    ----------
+    type
+        Standard origin type originating this hint.
+
+    Raises
+    ----------
+    BeartypeDecorHintPepException
+        If this hint does *not* originate from a standard origin type.
+
+    See Also
+    ----------
+    :func:`get_hint_pep_type_isinstanceable_or_none`
+        Related getter.
+    '''
+
+    # Origin type originating this object if any *OR* "None" otherwise.
+    hint_origin_type = get_hint_pep_type_isinstanceable_or_none(hint)
+
+    # If this type does *NOT* exist, raise an exception.
+    if hint_origin_type is None:
+        raise BeartypeDecorHintPepException(
+            f'Type hint {repr(hint)} not isinstanceable (i.e., does not '
+            f'originate from isinstanceable class).'
+        )
+    # Else, this type exists.
+
+    # Return this type.
+    return hint_origin_type
+
+
+def get_hint_pep_type_isinstanceable_or_none(
+    hint: Any) -> Optional[type]:
+    '''
+    **Standard origin type** (i.e., isinstanceable class declared by Python's
+    standard library such that *all* objects satisfying the passed
+    PEP-compliant type hint are instances of this class) originating this hint
+    if this hint originates from such a type *or* ``None`` otherwise (i.e., if
+    this hint does *not* originate from such a type).
+
+    This getter is intentionally *not* memoized (e.g., by the
+    :func:`callable_cached` decorator), as the implementation trivially reduces
+    to an efficient one-liner.
+
+    Caveats
+    ----------
+    **This high-level getter should always be called in lieu of the low-level**
+    :func:`get_hint_pep_origin_or_none` **getter or attempting to
+    directly access the low-level** ``__origin__`` **dunder attribute.**
+
+    Parameters
+    ----------
+    hint : object
+        Object to be inspected.
+
+    Returns
+    ----------
+    Optional[type]
+        Either:
+
+        * If this hint originates from a standard origin type, that type.
+        * Else, ``None``.
+
+    See Also
+    ----------
+    :func:`get_hint_pep_origin_type_isinstanceable`
+        Related getter.
+    :func:`get_hint_pep_origin_or_none`
+        Further details.
+    '''
+
+    # Sign uniquely identifying this hint.
+    hint_sign = get_hint_pep_sign(hint)
+
+    # Return either...
+    return (
+        # If this sign originates from an origin type, that type;
+        get_hint_pep_origin_or_none(hint)
+        if hint_sign in HINT_SIGNS_ORIGIN_ISINSTANCEABLE else
+        # Else, "None".
+        None
+    )
