@@ -13,40 +13,26 @@ This private submodule is *not* intended for importation by downstream callers.
 # ....................{ IMPORTS                           }....................
 from beartype.roar import (
     BeartypeDecorHintPepException,
-    BeartypeDecorHintPepDeprecatedWarning,
     BeartypeDecorHintPepUnsupportedException,
     BeartypeDecorHintPep484Exception,
+    BeartypeDecorHintPep585DeprecationWarning,
 )
-from beartype._cave._cavefast import HintGenericSubscriptedType
 from beartype._util.cache.utilcachecall import callable_cached
 from beartype._data.hint.pep.datapeprepr import (
-    HINTS_PEP484_REPR_PREFIX_DEPRECATED,
-    HINTS_REPR_PREFIX_DEPRECATED,
-)
+    HINTS_PEP484_REPR_PREFIX_DEPRECATED)
 from beartype._data.hint.pep.sign.datapepsigncls import HintSign
-from beartype._data.hint.pep.sign.datapepsigns import (
-    HintSignTypeVar,
-)
 from beartype._data.hint.pep.sign.datapepsignset import (
     HINT_SIGNS_SUPPORTED,
     HINT_SIGNS_TYPE_MIMIC,
 )
-from beartype._data.mod.datamod import (
-    TYPING_MODULE_NAMES,
-    TYPING_MODULE_NAMES_DOTTED,
-)
-from beartype._util.hint.pep.proposal.utilpep484 import (
-    HINT_PEP484_TUPLE_EMPTY,
-    is_hint_pep484_generic,
+from beartype._data.mod.datamod import TYPING_MODULE_NAMES
+from beartype._util.hint.pep.proposal.pep484.utilpep484 import (
     is_hint_pep484_ignorable_or_none,
 )
 from beartype._util.hint.pep.proposal.utilpep544 import (
     is_hint_pep544_ignorable_or_none)
 from beartype._util.hint.pep.proposal.utilpep585 import (
-    HINT_PEP585_TUPLE_EMPTY,
-    is_hint_pep585_builtin,
-    is_hint_pep585_generic,
-)
+    is_hint_pep585_builtin)
 from beartype._util.hint.pep.proposal.utilpep593 import (
     is_hint_pep593_ignorable_or_none)
 from beartype._util.mod.utilmodule import (
@@ -55,7 +41,8 @@ from beartype._util.mod.utilmodule import (
 )
 from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_7
 from beartype._util.utilobject import get_object_type_unless_type
-from typing import NoReturn, Type, TypeVar
+from beartype._util.utiltyping import TypeException
+from typing import NoReturn
 from warnings import warn
 
 # See the "beartype.cave" submodule for further commentary.
@@ -95,8 +82,8 @@ def die_if_hint_pep(
     hint: object,
 
     # Optional parameters.
-    hint_label: str = 'Type hint',
-    exception_cls: Type[Exception] = BeartypeDecorHintPepException,
+    exception_cls: TypeException = BeartypeDecorHintPepException,
+    exception_prefix: str = '',
 ) -> None:
     '''
     Raise an exception if the passed object is a **PEP-compliant type
@@ -110,30 +97,30 @@ def die_if_hint_pep(
     ----------
     hint : object
         Object to be validated.
-    hint_label : Optional[str]
-        Human-readable label prefixing this object's representation in the
-        exception message raised by this function. Defaults to
-        ``"Type hint"``.
-    exception_cls : Optional[type]
+    exception_cls : Type[Exception], optional
         Type of the exception to be raised by this function. Defaults to
         :class:`BeartypeDecorHintPepException`.
+    exception_prefix : str, optional
+        Human-readable label prefixing the representation of this object in the
+        exception message. Defaults to the empty string.
 
     Raises
     ----------
-    exception_cls
+    :exc:`exception_cls`
         If this object is a PEP-compliant type hint.
     '''
 
     # If this hint is PEP-compliant...
     if is_hint_pep(hint):
-        assert isinstance(hint_label, str), f'{repr(hint_label)} not string.'
         assert isinstance(exception_cls, type), (
             f'{repr(exception_cls)} not type.')
+        assert isinstance(exception_prefix, str), (
+            f'{repr(exception_prefix)} not string.')
 
         # Raise an exception of this class.
         raise exception_cls(
-            f'{hint_label} {repr(hint)} is PEP-compliant '
-            f'(e.g., rather than non-"typing" type).'
+            f'{exception_prefix}type hint {repr(hint)} is PEP-compliant '
+            f'(e.g., rather than isinstanceable class).'
         )
 
 
@@ -142,7 +129,8 @@ def die_unless_hint_pep(
     hint: object,
 
     # Optional parameters.
-    hint_label: str = 'Type hint',
+    exception_cls: TypeException = BeartypeDecorHintPepException,
+    exception_prefix: str = '',
 ) -> None:
     '''
     Raise an exception unless the passed object is a **PEP-compliant type
@@ -156,21 +144,28 @@ def die_unless_hint_pep(
     ----------
     hint : object
         Object to be validated.
-    hint_label : Optional[str]
-        Human-readable label prefixing this object's representation in the
-        exception message raised by this function. Defaults to ``"Type hint"``.
+    exception_cls : Type[Exception], optional
+        Type of the exception to be raised by this function. Defaults to
+        :class:`BeartypeDecorHintPepException`.
+    exception_prefix : str, optional
+        Human-readable label prefixing the representation of this object in the
+        exception message. Defaults to the empty string.
 
     Raises
     ----------
-    BeartypeDecorHintPepException
+    :exc:`exception_cls`
         If this object is *not* a PEP-compliant type hint.
     '''
 
     # If this hint is *NOT* PEP-compliant, raise an exception.
     if not is_hint_pep(hint):
-        assert isinstance(hint_label, str), f'{repr(hint_label)} not string.'
-        raise BeartypeDecorHintPepException(
-            f'{hint_label} {repr(hint)} not PEP-compliant.')
+        assert isinstance(exception_cls, type), (
+            f'{repr(exception_cls)} not type.')
+        assert isinstance(exception_prefix, str), (
+            f'{repr(exception_prefix)} not string.')
+
+        raise exception_cls(
+            f'{exception_prefix}type hint {repr(hint)} not PEP-compliant.')
 
 # ....................{ EXCEPTIONS ~ supported            }....................
 #FIXME: *DANGER.* This and the die_if_hint_pep_sign_unsupported() function make
@@ -183,7 +178,7 @@ def die_if_hint_pep_unsupported(
     hint: object,
 
     # Optional parameters.
-    hint_label: str = 'Annotated',
+    exception_prefix: str = '',
 ) -> None:
     '''
     Raise an exception if the passed object is a **PEP-compliant unsupported
@@ -217,9 +212,9 @@ def die_if_hint_pep_unsupported(
     ----------
     hint : object
         Object to be validated.
-    hint_label : Optional[str]
-        Human-readable label prefixing this object's representation in the
-        exception message raised by this function. Defaults to ``"Annotated"``.
+    exception_prefix : str, optional
+        Human-readable label prefixing the representation of this object in the
+        exception message. Defaults to the empty string.
 
     Raises
     ----------
@@ -244,10 +239,11 @@ def die_if_hint_pep_unsupported(
     # Else, this object is *NOT* a supported PEP-compliant type hint. In this
     # case, subsequent logic raises an exception specific to the passed
     # parameters.
-    assert isinstance(hint_label, str), f'{repr(hint_label)} not string.'
 
     # If this hint is *NOT* PEP-compliant, raise an exception.
-    die_unless_hint_pep(hint=hint, hint_label=hint_label)
+    die_unless_hint_pep(hint=hint, exception_prefix=exception_prefix)
+    assert isinstance(exception_prefix, str), (
+        f'{repr(exception_prefix)} not string.')
 
     # Else, this hint is PEP-compliant.
     #
@@ -255,8 +251,8 @@ def die_if_hint_pep_unsupported(
     # *ONLY* as a return annotation, raise an exception specific to this hint.
     if hint is NoReturn:
         raise BeartypeDecorHintPep484Exception(
-            f'{hint_label} {repr(hint)} invalid (i.e., "typing.NoReturn" '
-            f'valid only as non-nested return annotation).'
+            f'{exception_prefix}return type hint {repr(hint)} invalid (i.e., '
+            f'"typing.NoReturn" valid only as non-nested return annotation).'
         )
     # Else, this is any PEP-compliant type hint other than "typing.NoReturn".
     # In this case, raise a general-purpose exception.
@@ -267,7 +263,9 @@ def die_if_hint_pep_unsupported(
     # validating that expectation here.
     else:
         raise BeartypeDecorHintPepUnsupportedException(
-            f'{hint_label} {repr(hint)} currently unsupported by @beartype.')
+            f'{exception_prefix}type hint {repr(hint)} '
+            f'currently unsupported by @beartype.'
+        )
 
 
 def die_if_hint_pep_sign_unsupported(
@@ -275,7 +273,7 @@ def die_if_hint_pep_sign_unsupported(
     hint_sign: HintSign,
 
     # Optional parameters.
-    hint_label: str = 'Annotation sign',
+    exception_prefix: str = '',
 ) -> None:
     '''
     Raise an exception unless the passed object is a **supported PEP-compliant
@@ -290,9 +288,9 @@ def die_if_hint_pep_sign_unsupported(
     ----------
     hint : HintSign
         Sign to be validated.
-    hint_label : Optional[str]
-        Human-readable label prefixing this object's representation in the
-        exception message raised by this function. Defaults to 'Annotation'.
+    exception_prefix : str, optional
+        Human-readable label prefixing the representation of this object in the
+        exception message. Defaults to the empty string.
 
     Raises
     ----------
@@ -305,14 +303,15 @@ def die_if_hint_pep_sign_unsupported(
 
     # If this hint is *NOT* a supported sign, raise an exception.
     if hint_sign not in HINT_SIGNS_SUPPORTED:
-        assert isinstance(hint_label, str), f'{repr(hint_label)} not string.'
+        assert isinstance(exception_prefix, str), (
+            f'{repr(exception_prefix)} not string.')
         raise BeartypeDecorHintPepUnsupportedException(
-            f'{hint_label} sign {repr(hint_sign)} '
+            f'{exception_prefix}type hint sign {repr(hint_sign)} '
             f'currently unsupported by @beartype.'
         )
 
 # ....................{ WARNINGS                          }....................
-#FIXME: Resurrect support for the passed "hint_label" parameter. We've
+#FIXME: Resurrect support for the passed "warning_prefix" parameter. We've
 #currently disabled this parameter as it's typically just a non-human-readable
 #placeholder substring *NOT* intended to be exposed to end users (e.g.,
 #"$%ROOT_PITH_LABEL/~"). For exceptions, we simply catch raised exceptions and
@@ -324,7 +323,7 @@ def warn_if_hint_pep_deprecated(
     hint: object,
 
     # Optional parameters.
-    hint_label: str = 'Annotated',
+    warning_prefix: str = '',
 ) -> None:
     '''
     Emit a non-fatal warning if the passed PEP-compliant type hint is
@@ -339,14 +338,15 @@ def warn_if_hint_pep_deprecated(
     ----------
     hint : object
         PEP-compliant type hint to be inspected.
-    hint_label : Optional[str]
-        Human-readable label prefixing this object's representation in the
-        warning message emitted by this function. Defaults to ``"Annotated"``.
+    warning_prefix : str, optional
+        Human-readable label prefixing the representation of this object in the
+        warning message. Defaults to the empty string.
 
     Warns
     ----------
-    BeartypeDecorHintPepDeprecatedWarning
-        If this hint is deprecated.
+    :class:`BeartypeDecorHintPep585DeprecationWarning`
+        If this hint is a :pep:`484`-compliant type hint deprecated by
+        :pep:`585` *and* the active Python interpreter targets Python >= 3.9.
     '''
 
     # Substring of the machine-readable representation of this hint preceding
@@ -357,44 +357,33 @@ def warn_if_hint_pep_deprecated(
     # optimally efficient means of parsing trivial prefixes.
     hint_bare_repr, _, _ = repr(hint).partition('[')
 
-    # If this representation is deprecated...
-    if hint_bare_repr in HINTS_REPR_PREFIX_DEPRECATED:
-        #FIXME: Uncomment *AFTER* resolving the "FIXME:" above.
-        #FIXME: Unit test that this string contains *NO* non-human-readable
-        #placeholder substrings. Note that the existing
-        #"beartype_test.a00_unit.decor.code.test_codemain" submodule contains
-        #relevant logic currently disabled for reasons that hopefully no longer
-        #apply. *Urgh!*
+    #FIXME: Uncomment *AFTER* resolving the "FIXME:" above.
+    #FIXME: Unit test that this string contains *NO* non-human-readable
+    #placeholder substrings. Note that the existing
+    #"beartype_test.a00_unit.decor.code.test_codemain" submodule contains
+    #relevant logic currently disabled for reasons that hopefully no longer
+    #apply. *Urgh!*
+    # assert isinstance(exception_prefix, str), f'{repr(exception_prefix)} not string.'
 
-        # assert isinstance(hint_label, str), f'{repr(hint_label)} not string.'
-        #
-        # # Warning message to be emitted.
-        # warning_message = f'{hint_label} PEP type hint {repr(hint)} deprecated'
-
-        # Warning message to be emitted.
-        warning_message = f'Type hint {repr(hint)} deprecated'
-
-        # If this sign uniquely identifies PEP 484-compliant type hints
-        # originating from origin types (e.g., "typing.List[int]"), this sign
-        # has been deprecated by the equivalent PEP 585-compliant sign (e.g.,
-        # "list[int]"). In this case, suffix this warning message with
-        # pragmatic suggestions for resolving this deprecation.
-        if hint_bare_repr in HINTS_PEP484_REPR_PREFIX_DEPRECATED:
-            warning_message += (
-                ' by PEP 585. To resolve this, globally replace this hint by '
-                'the equivalent PEP 585 type hint '
-                '(e.g., "typing.List[int]" by "list[int]"). See also:\n'
-                '    https://www.python.org/dev/peps/pep-0585'
-            )
-        # Else, this sign is of unknown deprecation. In this case, simply
-        # terminate this unterminated sentence fragment as is.
-        else:
-            warning_message += '.'
-
-        # Emit this warning.
-        # print(f'Emitting {hint_label} hint {repr(hint)} deprecation warning...')
-        warn(warning_message, BeartypeDecorHintPepDeprecatedWarning)
-    # Else, this sign is *NOT* deprecated. In this case, reduce to a noop.
+    # If this hint is a PEP 484-compliant type hint originating from an origin
+    # type (e.g., "typing.List[int]"), this hint has been deprecated by the
+    # equivalent PEP 585-compliant type hint (e.g., "list[int]"). In this case,
+    # emit a non-fatal PEP 585-specific deprecation warning.
+    if hint_bare_repr in HINTS_PEP484_REPR_PREFIX_DEPRECATED:
+        warn(
+            (
+                f'PEP 484 type hint {repr(hint)} deprecated by PEP 585 '
+                f'scheduled for removal in the first Python version '
+                f'released after October 5th, 2025. To resolve this, '
+                f'either drop Python < 3.9 support and globally replace this '
+                f'hint by the equivalent PEP 585 type hint '
+                f'(e.g., "typing.List[int]" by "list[int]") or see this '
+                f'discussion topic for saner and more portable solutions:\n'
+                f'    https://github.com/beartype/beartype#pep-484-deprecations'
+            ),
+            BeartypeDecorHintPep585DeprecationWarning,
+        )
+    # Else, this hint is *NOT* deprecated. In this case, reduce to a noop.
 
 
 #FIXME: Unit test us up.
@@ -406,7 +395,7 @@ def warn_if_hint_pep_deprecated(
 #     hint: object,
 #
 #     # Optional parameters.
-#     hint_label: str = 'Annotated',
+#     exception_prefix: str = 'Annotated',
 # ) -> bool:
 #     '''
 #     Return ``True`` and emit a non-fatal warning only if the passed object is a
@@ -421,9 +410,9 @@ def warn_if_hint_pep_deprecated(
 #     ----------
 #     hint : object
 #         Object to be validated.
-#     hint_label : Optional[str]
+#     exception_prefix : Optional[str]
 #         Human-readable label prefixing this object's representation in the
-#         warning message emitted by this function. Defaults to ``"Annotated"``.
+#         warning message emitted by this function. Defaults to the empty string.
 #
 #     Returns
 #     ----------
@@ -451,15 +440,15 @@ def warn_if_hint_pep_deprecated(
 #
 #     # If this object is an unsupported PEP-compliant type hint...
 #     if not is_hint_pep_supported_test:
-#         assert isinstance(hint_label, str), f'{repr(hint_label)} not string.'
+#         assert isinstance(exception_prefix, str), f'{repr(exception_prefix)} not string.'
 #
 #         # If this hint is *NOT* PEP-compliant, raise an exception.
-#         die_unless_hint_pep(hint=hint, hint_label=hint_label)
+#         die_unless_hint_pep(hint=hint, exception_prefix=exception_prefix)
 #
 #         # Else, this hint is PEP-compliant. In this case, emit a warning.
 #         warn(
 #             (
-#                 f'{hint_label} PEP type hint {repr(hint)} '
+#                 f'{exception_prefix}PEP type hint {repr(hint)} '
 #                 f'currently unsupported by @beartype.'
 #             ),
 #             BeartypeDecorHintPepUnsupportedWarning
@@ -516,70 +505,6 @@ def is_hint_pep(hint: object) -> bool:
     # a PEP-compliant type hint.
     return get_hint_pep_sign_or_none(hint) is not None
 
-
-#FIXME: Unit test us up.
-def is_hint_pep_uncached(hint: object) -> bool:
-    '''
-    ``True`` only if the passed object is a **PEP-compliant non-self-cached
-    type hint** (i.e., PEP-compliant type hint that does *not* externally cache
-    itself somewhere).
-
-    Since most PEP-compliant type hints are self-caching, this function
-    returns:
-
-    * ``True`` for only:
-
-      * :pep:`484`-compliant subscripted generics under Python >= 3.9 (e.g.,
-        ``from typing import List; class MuhPep484List(List): pass;
-        MuhPep484List[int]``). See below for further commentary.
-      * :pep:`585`-compliant type hints, including both:
-
-        * Builtin :pep:`585`-compliant type hints (e.g., ``list[int]``).
-        * User-defined :pep:`585`-compliant generics (e.g.,
-          ``class MuhPep585List(list): pass; MuhPep585List[int]``).
-
-    * ``False`` for *all* other PEP-compliant type hints.
-
-    Caveats
-    ----------
-    This function *cannot* be meaningfully memoized, since the passed type hint
-    is *not* guaranteed to be cached somewhere. Only functions passed cached
-    type hints can be meaningfully memoized. Since this high-level function
-    internally defers to unmemoized low-level functions that are ``O(n)`` in
-    ``n`` the size of the inheritance hierarchy of this hint, this function
-    should be called sparingly. See the :mod:`beartype._decor._cache.cachehint`
-    submodule for further details.
-
-    This tester intentionally returns a false negative for :pep:`484`-compliant
-    generics subscripted by type variables under Python < 3.9. Although those
-    hints are technically non-self-cached, this tester falsely reports those
-    hints to be self-cached by returning ``False``. Why? Because correctly
-    detecting those hints as non-self-cached would require an unmemoized
-    ``O(n)`` search across the inheritance hierarchy of *all* passed objects
-    and thus all type hints annotating callables decorated by
-    :func:`beartype.beartype`. Since this failure only affects obsolete Python
-    versions *and* since the only harms induced by this failure are a slight
-    increase in space and time consumption for edge-case type hints unlikely to
-    actually be used in real-world code, this tradeoff is more than acceptable.
-    We're not the bad guy here. Right?
-
-    Parameters
-    ----------
-    hint : object
-        Object to be inspected.
-
-    Returns
-    ----------
-    bool
-        ``True`` only if this object is a PEP-compliant type hint.
-    '''
-
-    # Return true only if this hint is either:
-    # * A PEP 585-compliant type hint.
-    # * A PEP 484-compliant subscripted generic masquerading as a PEP
-    #   585-compliant type hint. *shrug*
-    return is_hint_pep585_builtin(hint)
-
 # ....................{ TESTERS ~ ignorable               }....................
 def is_hint_pep_ignorable(hint: object) -> bool:
     '''
@@ -622,16 +547,6 @@ def is_hint_pep_ignorable(hint: object) -> bool:
     # Sign uniquely identifying this hint.
     hint_sign = get_hint_pep_sign(hint)
 
-    #FIXME: Remove this *AFTER* properly supporting type variables. For
-    #now, ignoring type variables is required ta at least shallowly support
-    #generics parametrized by one or more type variables.
-
-    # If this hint is a type variable, return true. Type variables require
-    # non-trivial and currently unimplemented decorator support.
-    if hint_sign is HintSignTypeVar:
-        return True
-    # Else, this hint is *NOT* a type variable.
-
     # For each PEP-specific function testing whether this hint is an ignorable
     # type hint fully compliant with that PEP...
     for is_hint_pep_ignorable_tester in _IS_HINT_PEP_IGNORABLE_TESTERS:
@@ -720,7 +635,7 @@ def is_hint_pep_supported(hint: object) -> bool:
 #FIXME: Replace all hardcoded "'typing" strings throughout the codebase with
 #access of "TYPING_MODULE_NAMES" instead. We only see two remaining in:
 #* beartype/_util/hint/pep/proposal/utilpep544.py
-#* beartype/_util/hint/pep/proposal/utilpep484.py
+#* beartype._util.hint.pep.proposal.pep484.utilpep484.py
 #Thankfully, nobody really cares about generalizing these two edge cases to
 #"testing_extensions", so they're mostly fine for various definitions of fine.
 @callable_cached
@@ -884,11 +799,16 @@ is_hint_pep_type_typing.__doc__ = '''
         * Else, the class of this object is defined by a typing module.
     '''
 
-# ....................{ TESTERS ~ subscript               }....................
-def is_hint_pep_subscripted(hint: object) -> bool:
+# ....................{ TESTERS ~ args                    }....................
+#FIXME: Overkill. Replace directly with a simple test, please.
+#
+#Note that the corresponding unit test should be preserved, as that test is
+#essential to ensuring sanity across type hints and Python versions.
+def is_hint_pep_args(hint: object) -> bool:
     '''
     ``True`` only if the passed object is a **subscripted PEP-compliant type
-    hint** (i.e., PEP-compliant type hint indexed by one or more objects).
+    hint** (i.e., PEP-compliant type hint directly indexed by one or more
+    objects).
 
     This tester is intentionally *not* memoized (e.g., by the
     :func:`callable_cached` decorator), as the implementation trivially reduces
@@ -919,81 +839,17 @@ def is_hint_pep_subscripted(hint: object) -> bool:
     '''
 
     # Avoid circular import dependencies.
-    from beartype._util.hint.pep.utilpepget import (
-        get_hint_pep_args,
-        get_hint_pep_typevars,
-    )
+    from beartype._util.hint.pep.utilpepget import get_hint_pep_args
 
-    # Return true only if this hint is either...
-    return (
-        # A PEP-compliant subscripted generic under Python >= 3.9, including:
-        # * A PEP 484- or 585-compliant subscripted generic.
-        # * A PEP 585-compliant builtin type hint.
-        #
-        # Surprisingly, this test is *NOT* simply an optimization. Although
-        # most subscripted generics do preserve their subscripted objects as
-        # one or more arguments and/or type variables, PEP 585-compliant empty
-        # tuple type hints (i.e., "tuple[()]") do *NOT*. Thankfully, this
-        # simple and efficient test conveniently handles all edge cases
-        # associated with PEP 585.
-        isinstance(hint, HintGenericSubscriptedType) or
-        # Any other PEP-compliant type hint subscripted by one or more
-        # arguments and/or type variables. Note that this test is *NOT*
-        # reducible to merely:
-        #     bool(get_hint_pep_args(hint) or get_hint_pep_typevars(hint))
-        # Frankly, we have no idea why. We suspect we'd probably have to
-        # change the "or" operator in the above expression to the "+" operator,
-        # at which point the resulting operation is likely to be substantially
-        # slower than the simple series of tests performed here.
-        bool(get_hint_pep_args(hint)) or
-        bool(get_hint_pep_typevars(hint))
-    )
+    # Return true only if this hint is subscripted by one or more arguments.
+    return bool(get_hint_pep_args(hint))
 
-# ....................{ TESTERS ~ subscript : typevar     }....................
-def is_hint_pep_typevar(hint: object) -> bool:
-    '''
-    ``True`` only if the passed object either is a PEP-compliant **type
-    variable** (i.e., instance of the :class:`TypeVar` class).
-
-    This tester is intentionally *not* memoized (e.g., by the
-    :func:`callable_cached` decorator), as the implementation trivially reduces
-    to an efficient one-liner.
-
-    Motivation
-    ----------
-    Since type variables are not themselves types but rather placeholders
-    dynamically replaced with types by type checkers according to various
-    arcane heuristics, both type variables and types parametrized by type
-    variables warrant special-purpose handling.
-
-    Parameters
-    ----------
-    hint : object
-        Object to be inspected.
-
-    Returns
-    ----------
-    bool
-        ``True`` only if this object is a type variable.
-    '''
-
-    # Return true only if the type of this hint is that of all type variables.
-    #
-    # Note that the "typing.TypeVar" class prohibits subclassing: e.g.,
-    #     >>> import typing as t
-    #     >>> class MutTypeVar(t.TypeVar): pass
-    #     TypeError: Cannot subclass special typing classes
-    #
-    # Ergo, the object identity test performed here both suffices and is more
-    # efficient than the equivalent general-purpose test, which requires an
-    # implicit breadth- or depth-first search over the method resolution order
-    # (MRO) of all superclasses of this object: e.g.,
-    #     # This is potentially *MUCH* slower. It's the little things in life.
-    #     return isinstance(hint, TypeVar)
-    return hint.__class__ is TypeVar
-
-
-def is_hint_pep_typevared(hint: object) -> bool:
+# ....................{ TESTERS ~ typevars                }....................
+#FIXME: Overkill. Replace directly with a simple test, please.
+#
+#Note that the corresponding unit test should be preserved, as that test is
+#essential to ensuring sanity across type hints and Python versions.
+def is_hint_pep_typevars(hint: object) -> bool:
     '''
     ``True`` only if the passed object is a PEP-compliant type hint
     parametrized by one or more **type variables** (i.e., instances of the
@@ -1049,17 +905,17 @@ def is_hint_pep_typevared(hint: object) -> bool:
     ----------
         >>> import typing
         >>> from beartype._util.hint.pep.utilpeptest import (
-        ...     is_hint_pep_typevared)
+        ...     is_hint_pep_typevars)
         >>> T = typing.TypeVar('T')
         >>> class UserList(typing.List[T]): pass
         # Unparametrized type hint.
-        >>> is_hint_pep_typevared(typing.List[int])
+        >>> is_hint_pep_typevars(typing.List[int])
         False
         # Directly parametrized type hint.
-        >>> is_hint_pep_typevared(typing.List[T])
+        >>> is_hint_pep_typevars(typing.List[T])
         True
         # Superclass-parametrized type hint.
-        >>> is_hint_pep_typevared(UserList)
+        >>> is_hint_pep_typevars(UserList)
         True
     '''
 
@@ -1070,111 +926,3 @@ def is_hint_pep_typevared(hint: object) -> bool:
     # variables, trivially detected by testing whether the tuple of all type
     # variables parametrizing this hint is non-empty.
     return bool(get_hint_pep_typevars(hint))
-
-# ....................{ TESTERS ~ kind : generic          }....................
-@callable_cached
-def is_hint_pep_generic(hint: object) -> bool:
-    '''
-    ``True`` only if the passed object is a **generic** (i.e., class
-    superficially subclassing at least one PEP-compliant type hint that is
-    possibly *not* an actual class).
-
-    Specifically, this tester returns ``True`` only if this object is a class
-    that is either:
-
-    * A :pep:`585`-compliant generic as tested by the lower-level
-      :func:`is_hint_pep585_generic` function.
-    * A :pep:`484`-compliant generic as tested by the lower-level
-      :func:`is_hint_pep484_generic` function.
-
-    This tester is memoized for efficiency. Although the implementation
-    trivially reduces to a one-liner, constant factors associated with that
-    one-liner are non-negligible. Moreover, this tester is called frequently
-    enough to warrant its reduction to an efficient lookup.
-
-    Parameters
-    ----------
-    hint : object
-        Object to be inspected.
-
-    Returns
-    ----------
-    bool
-        ``True`` only if this object is a generic.
-
-    See Also
-    ----------
-    :func:`is_hint_pep_typevared`
-        Commentary on the relation between generics and parametrized hints.
-    '''
-
-    # Return true only if this hint is...
-    return (
-        # A PEP 484-compliant generic. Note this test trivially reduces to
-        # an O(1) operation and is thus tested first.
-        is_hint_pep484_generic(hint) or
-        # A PEP 585-compliant generic. Note this test is O(n) in n the
-        # number of pseudo-superclasses originally subclassed by this
-        # generic and is thus tested last.
-        is_hint_pep585_generic(hint)
-    )
-
-# ....................{ TESTERS ~ kind : tuple            }....................
-def is_hint_pep_tuple_empty(hint: object) -> bool:
-    '''
-    ``True`` only if the passed object is a PEP-compliant **empty fixed-length
-    tuple hint** (i.e., PEP-compliant type hint constraining piths to be the
-    empty tuple).
-
-    This tester is intentionally *not* memoized (e.g., by the
-    :func:`callable_cached` decorator), as this tester is only called under
-    fairly uncommon edge cases.
-
-    Motivation
-    ----------
-    Since type variables are not themselves types but rather placeholders
-    dynamically replaced with types by type checkers according to various
-    arcane heuristics, both type variables and types parametrized by type
-    variables warrant special-purpose handling.
-
-    Parameters
-    ----------
-    hint : object
-        Object to be inspected.
-
-    Returns
-    ----------
-    bool
-        ``True`` only if this object is a type variable.
-    '''
-
-    # Return true only if this hint resembles either the PEP 484- or
-    # 585-compliant fixed-length empty tuple type hint. Since there only exist
-    # two such hints *AND* comparison against these hints is mostly fast, this
-    # test is efficient in the general case.
-    #
-    # Note that this test may also be inefficiently performed by explicitly
-    # obtaining this hint's sign and then subjecting this hint to specific
-    # tests conditionally depending on which sign and thus PEP this hint
-    # complies with: e.g.,
-    #     # Return true only if this hint is either...
-    #     return true (
-    #         # A PEP 585-compliant "tuple"-based hint subscripted by no
-    #         # child hints *OR*...
-    #         (
-    #             hint.__origin__ is tuple and
-    #             hint_childs_len == 0
-    #         ) or
-    #         # A PEP 484-compliant "typing.Tuple"-based hint subscripted
-    #         # by exactly one child hint *AND* this child hint is the
-    #         # empty tuple,..
-    #         (
-    #             hint.__origin__ is Tuple and
-    #             hint_childs_len == 1 and
-    #             hint_childs[0] == ()
-    #         )
-    #     )
-    return (
-        hint == HINT_PEP585_TUPLE_EMPTY or
-        hint == HINT_PEP484_TUPLE_EMPTY
-    )
