@@ -4,14 +4,15 @@
 # See "LICENSE" for further details.
 
 '''
-**Beartype PEP-agnostic type hint tester utilities** (i.e., callables
-validating arbitrary objects to be PEP-agnostic type hints).
+Project-wide **PEP-agnostic type hint tester utilities** (i.e., callables
+validating arbitrary objects to be type hints supported by :mod:`beartype`,
+regardless of whether those hints comply with PEP standards or not).
 
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                           }....................
-from beartype.roar import BeartypeDecorHintForwardRefException
+from beartype._data.hint.pep.datapeprepr import HINTS_REPR_IGNORABLE_SHALLOW
 from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.hint.nonpep.utilnonpeptest import (
     die_unless_hint_nonpep,
@@ -22,8 +23,6 @@ from beartype._util.hint.pep.utilpeptest import (
     is_hint_pep,
     is_hint_pep_supported,
 )
-from beartype._data.hint.datahint import HINT_BASES_FORWARDREF
-from beartype._data.hint.pep.datapeprepr import HINTS_REPR_IGNORABLE_SHALLOW
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
@@ -34,7 +33,7 @@ def die_unless_hint(
     hint: object,
 
     # Optional parameters.
-    hint_label: str = 'Annotated',
+    exception_prefix: str = '',
 ) -> None:
     '''
     Raise an exception unless the passed object is a **supported type hint**
@@ -52,7 +51,7 @@ def die_unless_hint(
     Efficiency
     ----------
     This validator is effectively (but technically *not*) memoized. Since the
-    passed ``hint_label`` parameter is typically unique to each call to this
+    passed ``exception_prefix`` parameter is typically unique to each call to this
     validator, memoizing this validator would uselessly consume excess space
     *without* improving time efficiency. Instead, this validator first calls
     the memoized :func:`is_hint_pep` tester. If that tester returns ``True``,
@@ -65,16 +64,16 @@ def die_unless_hint(
     ----------
     hint : object
         Object to be validated.
-    hint_label : Optional[str]
-        Human-readable label prefixing this object's representation in the
-        exception message raised by this function. Defaults to ``"Annotated"``.
+    exception_prefix : str, optional
+        Human-readable label prefixing the representation of this object in the
+        exception message. Defaults to the empty string.
 
     Raises
     ----------
     BeartypeDecorHintPepUnsupportedException
         If this object is a PEP-compliant type hint currently unsupported by
         the :func:`beartype.beartype` decorator.
-    BeartypeDecorHintNonPepException
+    BeartypeDecorHintNonpepException
         If this object is neither:
 
         * A PEP-noncompliant type hint.
@@ -94,35 +93,12 @@ def die_unless_hint(
     # If this hint is PEP-compliant, raise an exception only if this hint is
     # currently unsupported by @beartype.
     if is_hint_pep(hint):
-        die_if_hint_pep_unsupported(hint=hint, hint_label=hint_label)
+        die_if_hint_pep_unsupported(hint=hint, exception_prefix=exception_prefix)
 
     # Else, this hint is *NOT* PEP-compliant. In this case, raise an exception
     # only if this hint is also *NOT* PEP-noncompliant. By definition, all
     # PEP-noncompliant type hints are supported by @beartype.
-    die_unless_hint_nonpep(hint=hint, hint_label=hint_label)
-
-# ....................{ VALIDATORS ~ forwardref           }....................
-def die_unless_hint_forwardref(hint: object) -> None:
-    '''
-    Raise an exception unless the passed object is a **forward reference type
-    hint** (i.e., object indirectly referring to a user-defined class that
-    typically has yet to be defined).
-
-    Parameters
-    ----------
-    hint : object
-        Object to be validated.
-
-    Raises
-    ----------
-    BeartypeDecorHintForwardRefException
-        If this object is *not* a forward reference type hint.
-    '''
-
-    # If this is *NOT* a forward reference type hint, raise an exception.
-    if not is_hint_forwardref(hint):
-        raise BeartypeDecorHintForwardRefException(
-            f'Type hint {repr(hint)} not forward reference.')
+    die_unless_hint_nonpep(hint=hint, exception_prefix=exception_prefix)
 
 # ....................{ TESTERS                           }....................
 @callable_cached
@@ -168,7 +144,7 @@ def is_hint(hint: object) -> bool:
         is_hint_pep_supported(hint) if is_hint_pep(hint) else
         # This is a PEP-noncompliant type hint, which by definition is
         # necessarily supported by @beartype.
-        is_hint_nonpep(hint)
+        is_hint_nonpep(hint=hint, is_str_valid=True)
     )
 
 # ....................{ TESTERS ~ ignorable               }....................
@@ -209,39 +185,3 @@ def is_hint_ignorable(hint: object) -> bool:
     # Since this hint is also *NOT* shallowly ignorable, this hint is
     # unignorable. In this case, return false.
     return False
-
-# ....................{ TESTERS ~ forwardref              }....................
-def is_hint_forwardref(hint: object) -> bool:
-    '''
-    ``True`` only if the passed object is a **forward reference type hint**
-    (i.e., object indirectly referring to a user-defined class that typically
-    has yet to be defined).
-
-    Specifically, this tester returns ``True`` only if this object is either:
-
-    * A string whose value is the syntactically valid name of a class.
-    * An instance of the :class:`typing.ForwardRef` class. The :mod:`typing`
-      module implicitly replaces all strings subscripting :mod:`typing` objects
-      (e.g., the ``MuhType`` in ``List['MuhType']``) with
-      :class:`typing.ForwardRef` instances containing those strings as instance
-      variables, for nebulous reasons that make little justifiable sense but
-      what you gonna do 'cause this is 2020. *Fight me.*
-
-    This tester is intentionally *not* memoized (e.g., by the
-    :func:`callable_cached` decorator), as the implementation trivially reduces
-    to an efficient one-liner.
-
-    Parameters
-    ----------
-    hint : object
-        Object to be inspected.
-
-    Returns
-    ----------
-    bool
-        ``True`` only if this object is a forward reference type hint.
-    '''
-
-    # Return true only if this hint is an instance of a PEP-compliant forward
-    # reference superclass.
-    return isinstance(hint, HINT_BASES_FORWARDREF)
