@@ -10,17 +10,19 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                           }....................
+from beartype._util.cache.utilcachecall import callable_cached
 from platform import python_implementation
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
 
 # ....................{ TESTERS                           }....................
-#FIXME: Inefficient. Just wrap this in a cached function call instead: e.g.,
-#    @callable_cached
-#    def is_pypy() -> bool:
-#        return python_implementation() == 'PyPy'
-IS_PYPY = python_implementation() == 'PyPy'
-'''
-``True`` only if the current Python interpreter is PyPy.
-'''
+@callable_cached
+def is_py_pypy() -> bool:
+    '''
+    ``True`` only if the active Python interpreter is **PyPy**.
+
+    This tester is memoized for efficiency.
+    '''
+
+    return python_implementation() == 'PyPy'
