@@ -4,18 +4,20 @@
 # See "LICENSE" for further details.
 
 '''
-**Beartype string joining utilities** (i.e., callables joining passed
+Project-wide **string joining utilities** (i.e., callables joining passed
 strings into new strings delimited by passed substring delimiters).
 
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                           }....................
+from beartype._util.utiltyping import IterableStrs
 from collections.abc import Iterable, Sequence
+from typing import Iterable as typing_Iterable
 
 # ....................{ JOINERS                           }....................
 def join_delimited(
-    strs: 'Iterable[str]',
+    strs: IterableStrs,
     delimiter_if_two: str,
     delimiter_if_three_or_more_nonlast: str,
     delimiter_if_three_or_more_last: str
@@ -96,9 +98,8 @@ def join_delimited(
     # If two strings are passed, return these strings delimited appropriately.
     elif num_strs == 2:
         return f'{strs[0]}{delimiter_if_two}{strs[1]}'
-
     # Else, three or more strings are passed.
-    #
+
     # All such strings except the last two, delimited appropriately.
     strs_nonlast = delimiter_if_three_or_more_nonlast.join(strs[0:-2])
 
@@ -109,10 +110,10 @@ def join_delimited(
     return f'{strs_nonlast}{delimiter_if_three_or_more_nonlast}{strs_last}'
 
 # ....................{ JOINERS ~ disjunction             }....................
-def join_delimited_disjunction(strs: 'Iterable[str]') -> str:
+def join_delimited_disjunction(strs: IterableStrs) -> str:
     '''
     Concatenate the passed iterable of zero or more strings delimited by commas
-    and/or the conjunction "or" (conditionally depending on both the length of
+    and/or the disjunction "or" (conditionally depending on both the length of
     this iterable and index of each string in this iterable), yielding a
     human-readable string listing arbitrarily many substrings disjunctively.
 
@@ -121,12 +122,12 @@ def join_delimited_disjunction(strs: 'Iterable[str]') -> str:
     * If this iterable contains no strings, the empty string.
     * If this iterable contains one string, this string as is is unmodified.
     * If this iterable contains two strings, these strings delimited by the
-      conjunction "or".
+      disjunction "or".
     * If this iterable contains three or more strings, a string listing these
       contained strings such that:
 
       * All contained strings except the last two are suffixed by commas.
-      * The last two contained strings are delimited by the conjunction "or".
+      * The last two contained strings are delimited by the disjunction "or".
 
     Parameters
     ----------
@@ -148,17 +149,17 @@ def join_delimited_disjunction(strs: 'Iterable[str]') -> str:
     )
 
 
-def join_delimited_disjunction_classes(classes: 'Iterable[type]') -> str:
+def join_delimited_disjunction_types(types: typing_Iterable[type]) -> str:
     '''
     Concatenate the human-readable classname of each class in the passed
-    iterable delimited by commas and/or the conjunction "or" (conditionally
+    iterable delimited by commas and/or the disjunction "or" (conditionally
     depending on both the length of this iterable and index of each string in
     this iterable), yielding a human-readable string listing arbitrarily many
     classnames disjunctively.
 
     Parameters
     ----------
-    strs : Iterable[type]
+    types : Iterable[type]
         Iterable of all classes whose human-readable classnames are to be
         concatenated disjunctively.
 
@@ -169,7 +170,7 @@ def join_delimited_disjunction_classes(classes: 'Iterable[type]') -> str:
     '''
 
     # Avoid circular import dependencies.
-    from beartype._util.text.utiltextlabel import label_class
+    from beartype._util.text.utiltextlabel import label_type
 
     # Make it so, ensign.
-    return join_delimited_disjunction(label_class(cls) for cls in classes)
+    return join_delimited_disjunction(label_type(cls) for cls in types)
