@@ -12,7 +12,7 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                           }....................
 from beartype.roar._roarwarn import _BeartypeUtilCallableWarning
-from beartype._util.utilobject import get_object_scopes_name
+from beartype._util.utilobject import get_object_basename_scoped
 from collections.abc import Callable
 from pprint import saferepr
 from re import (
@@ -27,7 +27,7 @@ def represent_object(
     obj: object,
 
     # Optional parameters.
-    max_len: int = 76,
+    max_len: int = 96,
     is_strip_from_newline_first: bool = True,
 ) -> str:
     """
@@ -79,7 +79,7 @@ def represent_object(
         Object to be represented.
     max_len: int, optional
         Maximum length of the string to be returned. Defaults to a standard
-        line length of 80 characters minus output indentation of 4 characters.
+        line length of 100 characters minus output indentation of 4 characters.
 
     Returns
     ----------
@@ -90,7 +90,7 @@ def represent_object(
     assert isinstance(max_len, int), f'{repr(max_len)} not integer.'
 
     # String describing the passed object. Note that:
-    # * This Representation quote-protects all newlines in this representation.
+    # * This representation quote-protects all newlines in this representation.
     #   Ergo, "\n" *MUST* be matched as r"\n" instead below.
     # * For debuggability, the verbose (albeit less readable) output of repr()
     #   is preferred to the terse (albeit more readable) output of str().
@@ -225,5 +225,5 @@ def represent_func(
         if is_func_lambda(func) else
         # Else, this callable is *NOT* a pure-Python lambda function. In this
         # case, the fully-qualified name of this non-lambda function.
-        f'{get_object_scopes_name(func)}()'
+        f'{get_object_basename_scoped(func)}()'
     )
