@@ -33,20 +33,27 @@ Instead, callers are expected to (in order):
 # names (e.g., "from argparse import ArgumentParser as _ArgumentParser" rather
 # than merely "from argparse import ArgumentParser").
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-from beartype.vale._valeis import Is
-from beartype.vale._valeisobj import IsAttr
-from beartype.vale._valeisoper import IsEqual
+from beartype.vale._factory._valeis import _IsFactory
+from beartype.vale._factory._valeiscls import _IsSubclassFactory
+from beartype.vale._factory._valeisobj import _IsAttrFactory
+from beartype.vale._factory._valeisoper import _IsEqualFactory
+
+# ....................{ SINGLETONS                        }....................
+# Public factory singletons instantiating these private factory classes.
+Is = _IsFactory(basename='Is')
+IsAttr = _IsAttrFactory(basename='IsAttr')
+IsEqual = _IsEqualFactory(basename='IsEqual')
+IsSubclass = _IsSubclassFactory(basename='IsSubclass')
+
+# Delete all private factory classes imported above for safety.
+del (
+    _IsFactory,
+    _IsAttrFactory,
+    _IsEqualFactory,
+    _IsSubclassFactory,
+)
 
 # ....................{ TODO                              }....................
-#FIXME: Mypy completely fails to support the __class_getitem__() dunder method,
-#which almost certainly constitutes a bug -- although they will, of course,
-#argue otherwise, because they are mypy. Nonetheless, let's at least try
-#reporting this. *ANY* attempt to subscript a type defining __class_getitem__()
-#causes mypy to emit a false positive resembling:
-#    error: The type "Type[IsAttr]" is not generic and not indexable  [misc]
-#When submitting this report, we should also note that Django developers have
-#hit similar issues in a recent PR. Ergo, this is a meaningful issue.
-
 #FIXME: As intelligently requested by @Saphyel at #32, add support for
 #additional classes support constraints resembling:
 #
@@ -66,17 +73,17 @@ from beartype.vale._valeisoper import IsEqual
 #  * Range.
 #  * DivisibleBy.
 
-#FIXME: Add a new _SubscriptedIs.get_cause_or_none() method with the same
+#FIXME: Add a new BeartypeValidator.get_cause_or_none() method with the same
 #signature and docstring as the existing CauseSleuth.get_cause_or_none()
-#method. This new _SubscriptedIs.get_cause_or_none() method should then be
+#method. This new BeartypeValidator.get_cause_or_none() method should then be
 #called by the "_peperrorannotated" submodule to generate human-readable
 #exception messages. Note that this implies that:
-#* The _SubscriptedIs.__init__() method will need to additionally accept a new
+#* The BeartypeValidator.__init__() method will need to additionally accept a new
 #  mandatory "get_cause_or_none: Callable[[], Optional[str]]" parameter, which
 #  that method should then localize to "self.get_cause_or_none".
-#* Each __class_getitem__() dunder method of each "_IsABC" subclass will need
+#* Each __class_getitem__() dunder method of each "_BeartypeValidatorFactoryABC" subclass will need
 #  to additionally define and pass that callable when creating and returning
-#  its "_SubscriptedIs" instance.
+#  its "BeartypeValidator" instance.
 
 #FIXME: *BRILLIANT IDEA.* Holyshitballstime. The idea here is that we can
 #leverage all of our existing "beartype.is" infrastructure to dynamically
