@@ -13,20 +13,80 @@ cases on behalf of higher-level unit test submodules.
 # ....................{ IMPORTS                           }....................
 import builtins
 from beartype._data.mod.datamod import BUILTINS_MODULE_NAME
+from contextlib import contextmanager
 from sys import exc_info, implementation
-from typing import Callable
+from typing import (
+    AsyncGenerator,
+    Callable,
+    ContextManager,
+    Coroutine,
+    Generator,
+)
+
+# ....................{ CLASSES ~ hierarchy : 1           }....................
+# Arbitrary class hierarchy.
 
-# ....................{ CLASSES                           }....................
 class Class(object):
     '''
     Arbitrary pure-Python class defining an arbitrary method.
     '''
 
     def instance_method(self):
-        '''Arbitrary pure-Python instance method.'''
+        '''
+        Arbitrary pure-Python instance method.
+        '''
 
         pass
 
+
+class Subclass(Class):
+    '''
+    Arbitrary pure-Python subclass of an arbitrary pure-Python superclass.
+    '''
+
+    pass
+
+
+class SubclassSubclass(Subclass):
+    '''
+    Arbitrary pure-Python subclass of an arbitrary pure-Python subclass of an
+    arbitrary pure-Python superclass.
+    '''
+
+    pass
+
+# ....................{ CLASSES ~ hierarchy : 2           }....................
+# Yet another arbitrary class hierarchy.
+
+class OtherClass(object):
+    '''
+    Arbitrary pure-Python class defining an arbitrary method.
+    '''
+
+    def instance_method(self):
+        '''
+        Arbitrary pure-Python instance method.
+        '''
+
+        pass
+
+
+class OtherSubclass(OtherClass):
+    '''
+    Arbitrary pure-Python subclass of an arbitrary pure-Python superclass.
+    '''
+
+    pass
+
+
+class OtherSubclassSubclass(OtherSubclass):
+    '''
+    Arbitrary pure-Python subclass of an arbitrary pure-Python subclass of an
+    arbitrary pure-Python superclass.
+    '''
+
+    pass
+
 # ....................{ CLASSES ~ isinstance              }....................
 class NonIsinstanceableMetaclass(type):
     '''
@@ -50,7 +110,68 @@ class NonIsinstanceableClass(object, metaclass=NonIsinstanceableMetaclass):
 
     pass
 
-# ....................{ CALLABLES                         }....................
+# ....................{ CLASSES ~ issubclass              }....................
+class NonIssubclassableMetaclass(type):
+    '''
+    Metaclass overriding the ``__subclasscheck__()`` dunder method to
+    unconditionally raise an exception, preventing classes with this metaclass
+    from being passed as the second parameter to the :func:`issubclass`
+    builtin.
+    '''
+
+    def __subclasscheck__(self, obj: object) -> bool:
+        raise TypeError(
+            f'{self} not passable as second parameter to issubclass().')
+
+
+class NonIssubclassableClass(object, metaclass=NonIssubclassableMetaclass):
+    '''
+    Class whose metaclass overrides the ``__subclasscheck__()`` dunder method
+    to unconditionally raise an exception, preventing this class from being
+    passed as the second parameter to the :func:`issubclass` builtin.
+    '''
+
+    pass
+
+# ....................{ CALLABLES ~ async : factory       }....................
+# Note that we intentionally avoid declaring a factory function for deprecated
+# generator-based coroutines decorated by either the types.coroutine() or
+# asyncio.coroutine() decorators. CPython 3.10 removes support for these
+# decorators and thus generator-based coroutines. See also:
+#     https://docs.python.org/3/library/asyncio-task.html#asyncio.coroutine
+
+async def async_generator_factory() -> AsyncGenerator[None, None]:
+    '''
+    Arbitrary pure-Python asynchronous generator factory function.
+    '''
+
+    yield
+
+
+async def async_coroutine_factory() -> Coroutine[None, None, None]:
+    '''
+    Arbitrary pure-Python asynchronous non-generator coroutine factory
+    function.
+    '''
+
+    pass
+
+# ....................{ CALLABLES ~ async : instance      }....................
+async_generator = async_generator_factory()
+'''
+Arbitrary pure-Python asynchronous generator.
+'''
+
+
+async_coroutine = async_coroutine_factory()
+'''
+Arbitrary pure-Python asynchronous non-generator coroutine.
+'''
+
+# Prevent Python from emitting "ResourceWarning" warnings.
+async_coroutine.close()
+
+# ....................{ CALLABLES ~ sync                  }....................
 def function():
     '''
     Arbitrary pure-Python function.
@@ -59,25 +180,6 @@ def function():
     pass
 
 
-def closure_cell_factory():
-    '''
-    Arbitrary pure-Python closure cell factory function.
-    '''
-
-    # Arbitrary non-local variable.
-    outer_variable = 1
-
-    def closure():
-        '''
-        Arbitrary pure-Python closure.
-        '''
-
-        nonlocal outer_variable
-
-    # Return this closure's first and only cell variable.
-    return closure.__closure__[0]
-
-
 def decorator(func: Callable) -> Callable:
     '''
     **Identity decorator** (i.e., decorator returning the passed callable
@@ -92,44 +194,92 @@ def decorator(func: Callable) -> Callable:
     return func
 
 
-def generator_factory():
+@contextmanager
+def context_manager_factory(obj: object) -> ContextManager[object]:
     '''
-    Arbitrary pure-Python generator factory function.
+    Create and return a new **identity context manager** (i.e., context
+    manager trivially yielding the passed object).
+    '''
+
+    yield obj
+
+# ....................{ CALLABLES ~ sync : generator      }....................
+def sync_generator_factory() -> Generator[int, None, None]:
+    '''
+    Create and return a pure-Python generator yielding a single integer,
+    accepting nothing, and returning nothing.
     '''
 
     yield 1
 
-# ....................{ CALLABLES ~ async                 }....................
-async def async_generator_factory():
+
+def sync_generator_factory_yield_int_send_float_return_str() -> (
+    Generator[int, float, str]):
     '''
-    Arbitrary pure-Python asynchronous generator factory function.
+    Create and return a pure-Python generator yielding integers, accepting
+    floating-point numbers sent to this generator by the caller, and returning
+    strings.
+
+    See Also
+    ----------
+    https://www.python.org/dev/peps/pep-0484/#id39
+        ``echo_round`` function strongly inspiring this implementation, copied
+        verbatim from this subsection of :pep:`484`.
     '''
 
-    yield
+    # Initial value externally sent to this generator.
+    res = yield
 
+    while res:
+        res = yield round(res)
 
-async def coroutine_factory():
+    # Return a string constant.
+    return 'Unmarred, scarred revenant remnants'
+
+# ....................{ CALLABLES ~ sync : closure        }....................
+def closure_factory():
     '''
-    Arbitrary pure-Python coroutine factory function.
+    Arbitrary pure-Python closure factory function.
     '''
 
-    pass
+    # Arbitrary non-local variable.
+    outer_variable = 42
+
+    def closure():
+        '''
+        Arbitrary pure-Python closure.
+        '''
+
+        nonlocal outer_variable
+
+    # Return this closure.
+    return closure
 
 
-async_generator = async_generator_factory()
+def closure_cell_factory():
+    '''
+    Arbitrary pure-Python closure cell factory function.
+    '''
+
+    # Arbitrary non-local variable.
+    outer_variable = 1337
+
+    def closure():
+        '''
+        Arbitrary pure-Python closure.
+        '''
+
+        nonlocal outer_variable
+
+    # Return this closure's first and only cell variable.
+    return closure.__closure__[0]
+
+# ....................{ CALLABLES ~ sync : instance       }....................
+sync_generator = sync_generator_factory()
 '''
-Arbitrary pure-Python asynchronous generator.
+Arbitrary pure-Python synchronous generator.
 '''
 
-
-coroutine = coroutine_factory()
-'''
-Arbitrary pure-Python coroutine.
-'''
-
-# Prevent Python from emitting "ResourceWarning" warnings.
-coroutine.close()
-
 # ....................{ CONSTANTS                         }....................
 CALLABLE_CODE_OBJECT = function.__code__
 '''
@@ -182,14 +332,20 @@ Frozen set of C-based callables exercising edge cases.
 '''
 
 
+CALLABLES = CALLABLES_PYTHON | CALLABLES_C
+'''
+Frozen set of both pure-Python *and* C-based callables exercising edge cases.
+'''
+
+
 NON_CALLABLES = (
     CALLABLE_CODE_OBJECT,
     type.__dict__,      # Mapping Proxy Type
     implementation,     # Simple Namespace Type
+    async_coroutine,
     async_generator,
+    sync_generator,
     closure_cell_factory(), # Cell type
-    coroutine,
-    generator_factory(),
     TRACEBACK,
     TRACEBACK.tb_frame,
 )
