@@ -8,29 +8,7 @@ Project-wide :pep:`585`-compliant **type hint test data.**
 '''
 
 # ....................{ IMPORTS                           }....................
-import re
-from beartype._cave._cavefast import IntType
-from beartype._data.hint.pep.sign.datapepsigns import (
-    HintSignByteString,
-    HintSignCallable,
-    HintSignContextManager,
-    HintSignDict,
-    HintSignGenerator,
-    HintSignGeneric,
-    HintSignList,
-    HintSignMatch,
-    HintSignMutableSequence,
-    HintSignPattern,
-    HintSignSequence,
-    HintSignTuple,
-    HintSignType,
-)
 from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_9
-from beartype_test.a00_unit.data.hint.util.data_hintmetacls import (
-    HintPepMetadata,
-    HintPithSatisfiedMetadata,
-    HintPithUnsatisfiedMetadata,
-)
 
 # ....................{ ADDERS                            }....................
 def add_data(data_module: 'ModuleType') -> None:
@@ -53,20 +31,46 @@ def add_data(data_module: 'ModuleType') -> None:
 
     # ..................{ IMPORTS                           }..................
     # Defer Python >= 3.9-specific imports.
+    import re
+    from beartype._cave._cavefast import IntType
+    from beartype._data.hint.pep.sign.datapepsigns import (
+        HintSignByteString,
+        HintSignCallable,
+        HintSignContextManager,
+        HintSignDict,
+        HintSignGeneric,
+        HintSignList,
+        HintSignMatch,
+        HintSignMutableSequence,
+        HintSignPattern,
+        HintSignSequence,
+        HintSignTuple,
+        HintSignType,
+    )
+    from beartype_test.a00_unit.data.data_type import (
+        Class,
+        Subclass,
+        SubclassSubclass,
+        OtherClass,
+        OtherSubclass,
+        # OtherSubclassSubclass,
+        context_manager_factory,
+    )
+    from beartype_test.a00_unit.data.hint.util.data_hintmetacls import (
+        HintPepMetadata,
+        HintPithSatisfiedMetadata,
+        HintPithUnsatisfiedMetadata,
+    )
     from collections.abc import (
         ByteString,
         Callable,
         Container,
-        Generator,
         Iterable,
         MutableSequence,
         Sequence,
         Sized,
     )
-    from contextlib import (
-        AbstractContextManager,
-        contextmanager,
-    )
+    from contextlib import AbstractContextManager
     from re import Match, Pattern
     from typing import Any, TypeVar, Union
 
@@ -82,40 +86,6 @@ def add_data(data_module: 'ModuleType') -> None:
     User-defined generic :mod:`typing` type variable.
     '''
 
-    # ..................{ CALLABLES                         }..................
-    @contextmanager
-    def _make_context_manager(obj: object) -> AbstractContextManager[object]:
-        '''
-        Create and return a context manager trivially yielding the passed
-        object.
-        '''
-
-        yield obj
-
-
-    def _make_generator_yield_int_send_float_return_str() -> (
-        Generator[int, float, str]):
-        '''
-        Create and return a generator yielding integers, accepting
-        floating-point numbers sent to this generator by the caller, and
-        returning strings.
-
-        See Also
-        ----------
-        https://www.python.org/dev/peps/pep-0484/#id39
-            ``echo_round`` function strongly inspiring this implementation,
-            copied verbatim from this subsection of :pep:`484`.
-        '''
-
-        # Initial value externally sent to this generator.
-        res = yield
-
-        while res:
-            res = yield round(res)
-
-        # Return a string constant.
-        return 'Unmarred, scarred revanent remnants'
-
     # ..................{ CLASSES ~ generics : single       }..................
     class Pep585GenericUntypevaredSingle(list[str]):
         '''
@@ -237,6 +207,20 @@ def add_data(data_module: 'ModuleType') -> None:
         def __len__(self) -> bool:
             return len(self._iterable)
 
+    # ..................{ PRIVATE ~ forwardref              }..................
+    _TEST_PEP585_FORWARDREF_CLASSNAME = (
+        'beartype_test.a00_unit.data.data_type.Subclass')
+    '''
+    Fully-qualified classname of an arbitrary class guaranteed to be
+    importable.
+    '''
+
+
+    _TEST_PEP585_FORWARDREF_TYPE = Subclass
+    '''
+    Arbitrary class referred to by :data:`_PEP484_FORWARDREF_CLASSNAME`.
+    '''
+
     # ..................{ MAPPINGS                          }..................
     # Add PEP 585-specific test type hints to this dictionary global.
     data_module.HINTS_PEP_META.extend((
@@ -253,7 +237,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=ByteString[int],
             pep_sign=HintSignByteString,
-            stdlib_type=ByteString,
+            isinstanceable_type=ByteString,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Byte string constant.
@@ -270,7 +254,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=ByteString[IntType],
             pep_sign=HintSignByteString,
-            stdlib_type=ByteString,
+            isinstanceable_type=ByteString,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Byte array initialized from a byte string constant.
@@ -288,7 +272,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Callable[[], str],
             pep_sign=HintSignCallable,
-            stdlib_type=Callable,
+            isinstanceable_type=Callable,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Lambda function returning a string constant.
@@ -305,12 +289,12 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=AbstractContextManager[str],
             pep_sign=HintSignContextManager,
-            stdlib_type=AbstractContextManager,
+            isinstanceable_type=AbstractContextManager,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Context manager.
                 HintPithSatisfiedMetadata(
-                    pith=lambda: _make_context_manager(
+                    pith=lambda: context_manager_factory(
                         'We were mysteries, unwon'),
                     is_context_manager=True,
                     is_pith_factory=True,
@@ -327,7 +311,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=dict[int, str],
             pep_sign=HintSignDict,
-            stdlib_type=dict,
+            isinstanceable_type=dict,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Dictionary mapping integer keys to string values.
@@ -347,8 +331,8 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=dict[S, T],
             pep_sign=HintSignDict,
-            stdlib_type=dict,
-            is_typevared=True,
+            isinstanceable_type=dict,
+            is_typevars=True,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Dictionary mapping string keys to integer values.
@@ -364,23 +348,9 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # ................{ GENERATOR                         }................
-        # Flat generator.
-        HintPepMetadata(
-            hint=Generator[int, float, str],
-            pep_sign=HintSignGenerator,
-            stdlib_type=Generator,
-            is_pep585_builtin=True,
-            piths_satisfied_meta=(
-                # Generator yielding integers, accepting floating-point numbers
-                # sent to this generator by the caller, and returning strings.
-                HintPithSatisfiedMetadata(
-                    _make_generator_yield_int_send_float_return_str()),
-            ),
-            piths_unsatisfied_meta=(
-                # Lambda function returning a string constant.
-                HintPithUnsatisfiedMetadata(lambda: 'Cessation'),
-            ),
-        ),
+        # Note that testing generators requires creating generators, which
+        # require a different syntax to that of standard callables; ergo,
+        # generator type hints are tested elsewhere.
 
         # ................{ GENERICS ~ single                 }................
         # Note that PEP 585-compliant generics are *NOT* explicitly detected as
@@ -394,7 +364,7 @@ def add_data(data_module: 'ModuleType') -> None:
             pep_sign=HintSignGeneric,
             generic_type=Pep585GenericUntypevaredSingle,
             is_pep585_generic=True,
-            is_subscripted=False,
+            is_args=False,
             piths_satisfied_meta=(
                 # Subclass-specific generic list of string constants.
                 HintPithSatisfiedMetadata(Pep585GenericUntypevaredSingle((
@@ -420,7 +390,7 @@ def add_data(data_module: 'ModuleType') -> None:
             pep_sign=HintSignGeneric,
             generic_type=Pep585GenericTypevaredSingle,
             is_pep585_generic=True,
-            is_typevared=True,
+            is_typevars=True,
             piths_satisfied_meta=(
                 # Subclass-specific generic list of string constants.
                 HintPithSatisfiedMetadata(Pep585GenericTypevaredSingle((
@@ -447,7 +417,7 @@ def add_data(data_module: 'ModuleType') -> None:
             pep_sign=HintSignGeneric,
             generic_type=Pep585GenericTypevaredSingle,
             is_pep585_generic=True,
-            is_typevared=True,
+            is_typevars=True,
             piths_satisfied_meta=(
                 # Subclass-specific generic list of string constants.
                 HintPithSatisfiedMetadata(Pep585GenericTypevaredSingle((
@@ -475,7 +445,7 @@ def add_data(data_module: 'ModuleType') -> None:
             pep_sign=HintSignGeneric,
             generic_type=Pep585GenericUntypevaredMultiple,
             is_pep585_generic=True,
-            is_subscripted=False,
+            is_args=False,
             piths_satisfied_meta=(
                 # Subclass-specific generic 2-tuple of string constants.
                 HintPithSatisfiedMetadata(Pep585GenericUntypevaredMultiple((
@@ -501,7 +471,7 @@ def add_data(data_module: 'ModuleType') -> None:
             pep_sign=HintSignGeneric,
             generic_type=Pep585GenericTypevaredShallowMultiple,
             is_pep585_generic=True,
-            is_typevared=True,
+            is_typevars=True,
             piths_satisfied_meta=(
                 # Subclass-specific generic iterable of string constants.
                 HintPithSatisfiedMetadata(
@@ -525,7 +495,7 @@ def add_data(data_module: 'ModuleType') -> None:
             pep_sign=HintSignGeneric,
             generic_type=Pep585GenericTypevaredDeepMultiple,
             is_pep585_generic=True,
-            is_typevared=True,
+            is_typevars=True,
             is_type_typing=False,
             piths_satisfied_meta=(
                 # Subclass-specific generic iterable of 2-tuples of string
@@ -553,7 +523,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=list[Pep585GenericUntypevaredMultiple],
             pep_sign=HintSignList,
-            stdlib_type=list,
+            isinstanceable_type=list,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # List of subclass-specific generic 2-tuples of string
@@ -588,7 +558,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=list[object],
             pep_sign=HintSignList,
-            stdlib_type=list,
+            isinstanceable_type=list,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Empty list, which satisfies all hint arguments by definition.
@@ -611,7 +581,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=list[str],
             pep_sign=HintSignList,
-            stdlib_type=list,
+            isinstanceable_type=list,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Empty list, which satisfies all hint arguments by definition.
@@ -646,8 +616,8 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=list[T],
             pep_sign=HintSignList,
-            stdlib_type=list,
-            is_typevared=True,
+            isinstanceable_type=list,
+            is_typevars=True,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Empty list, which satisfies all hint arguments by definition.
@@ -670,7 +640,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Match[str],
             pep_sign=HintSignMatch,
-            stdlib_type=Match,
+            isinstanceable_type=Match,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Regular expression match of one or more string constants.
@@ -690,7 +660,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Pattern[str],
             pep_sign=HintSignPattern,
-            stdlib_type=Pattern,
+            isinstanceable_type=Pattern,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Regular expression string pattern.
@@ -703,6 +673,114 @@ def add_data(data_module: 'ModuleType') -> None:
             ),
         ),
 
+        # ................{ SUBCLASS                          }................
+        # Any type, semantically equivalent under PEP 484 to the unsubscripted
+        # "Type" singleton.
+        HintPepMetadata(
+            hint=type[Any],
+            pep_sign=HintSignType,
+            isinstanceable_type=type,
+            is_pep585_builtin=True,
+            piths_satisfied_meta=(
+                # Arbitrary class.
+                HintPithSatisfiedMetadata(float),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant.
+                HintPithUnsatisfiedMetadata('Coulomb‐lobed lobbyist’s Ģom'),
+            ),
+        ),
+
+        # "type" superclass, semantically equivalent to the unsubscripted
+        # "Type" singleton.
+        HintPepMetadata(
+            hint=type[type],
+            pep_sign=HintSignType,
+            isinstanceable_type=type,
+            is_pep585_builtin=True,
+            piths_satisfied_meta=(
+                # Arbitrary class.
+                HintPithSatisfiedMetadata(complex),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant.
+                HintPithUnsatisfiedMetadata('Had al-'),
+            ),
+        ),
+
+        # Specific class.
+        HintPepMetadata(
+            hint=type[Class],
+            pep_sign=HintSignType,
+            isinstanceable_type=type,
+            is_pep585_builtin=True,
+            piths_satisfied_meta=(
+                # Subclass of this class.
+                HintPithSatisfiedMetadata(Subclass),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant.
+                HintPithUnsatisfiedMetadata('Namely,'),
+                # Non-subclass of this class.
+                HintPithUnsatisfiedMetadata(str),
+            ),
+        ),
+
+        # Specific class deferred with a forward reference.
+        HintPepMetadata(
+            hint=type[_TEST_PEP585_FORWARDREF_CLASSNAME],
+            pep_sign=HintSignType,
+            isinstanceable_type=type,
+            is_pep585_builtin=True,
+            piths_satisfied_meta=(
+                # Subclass of this class.
+                HintPithSatisfiedMetadata(SubclassSubclass),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant.
+                HintPithUnsatisfiedMetadata('Jabbar‐disbarred'),
+                # Non-subclass of this class.
+                HintPithUnsatisfiedMetadata(dict),
+            ),
+        ),
+
+        # Two or more specific classes.
+        HintPepMetadata(
+            hint=type[Union[Class, OtherClass,]],
+            pep_sign=HintSignType,
+            isinstanceable_type=type,
+            is_pep585_builtin=True,
+            piths_satisfied_meta=(
+                # Arbitrary subclass of one class subscripting this hint.
+                HintPithSatisfiedMetadata(Subclass),
+                # Arbitrary subclass of another class subscripting this hint.
+                HintPithSatisfiedMetadata(OtherSubclass),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant.
+                HintPithUnsatisfiedMetadata('Jabberings'),
+                # Non-subclass of any classes subscripting this hint.
+                HintPithUnsatisfiedMetadata(set),
+            ),
+        ),
+
+        # Generic class.
+        HintPepMetadata(
+            hint=type[T],
+            pep_sign=HintSignType,
+            isinstanceable_type=type,
+            is_pep585_builtin=True,
+            is_typevars=True,
+            piths_satisfied_meta=(
+                # Arbitrary class.
+                HintPithSatisfiedMetadata(int),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant.
+                HintPithUnsatisfiedMetadata('Obligation, and'),
+            ),
+        ),
+
         # ................{ TUPLE ~ fixed                     }................
         # Empty tuple. Yes, this is ridiculous, useless, and non-orthogonal
         # with standard sequence syntax, which supports no comparable notion of
@@ -715,7 +793,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=tuple[()],
             pep_sign=HintSignTuple,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Empty tuple.
@@ -741,7 +819,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=tuple[Any, object,],
             pep_sign=HintSignTuple,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Tuple containing arbitrary items.
@@ -767,7 +845,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=tuple[float, Any, str,],
             pep_sign=HintSignTuple,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Tuple containing a floating-point number, string, and integer
@@ -817,7 +895,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=tuple[tuple[float, Any, str,], ...],
             pep_sign=HintSignTuple,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Tuple containing tuples containing a floating-point number,
@@ -869,9 +947,9 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=tuple[S, T],
             pep_sign=HintSignTuple,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
             is_pep585_builtin=True,
-            is_typevared=True,
+            is_typevars=True,
             piths_satisfied_meta=(
                 # Tuple containing a floating-point number and string (in that
                 # exact order).
@@ -895,7 +973,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=tuple[str, ...],
             pep_sign=HintSignTuple,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Tuple containing arbitrarily many string constants.
@@ -928,9 +1006,9 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=tuple[T, ...],
             pep_sign=HintSignTuple,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
             is_pep585_builtin=True,
-            is_typevared=True,
+            is_typevars=True,
             piths_satisfied_meta=(
                 # Tuple containing arbitrarily many string constants.
                 HintPithSatisfiedMetadata((
@@ -945,40 +1023,6 @@ def add_data(data_module: 'ModuleType') -> None:
             ),
         ),
 
-        # ................{ TYPE                              }................
-        # Builtin type.
-        HintPepMetadata(
-            hint=type[dict],
-            pep_sign=HintSignType,
-            stdlib_type=type,
-            is_pep585_builtin=True,
-            piths_satisfied_meta=(
-                # Builtin "dict" class itself.
-                HintPithSatisfiedMetadata(dict),
-            ),
-            piths_unsatisfied_meta=(
-                # String constant.
-                HintPithUnsatisfiedMetadata('Namely,'),
-            ),
-        ),
-
-        # Generic type.
-        HintPepMetadata(
-            hint=type[T],
-            pep_sign=HintSignType,
-            stdlib_type=type,
-            is_pep585_builtin=True,
-            is_typevared=True,
-            piths_satisfied_meta=(
-                # Builtin "int" class itself.
-                HintPithSatisfiedMetadata(int),
-            ),
-            piths_unsatisfied_meta=(
-                # String constant.
-                HintPithUnsatisfiedMetadata('Obligation, and'),
-            ),
-        ),
-
         # ................{ UNION ~ nested                    }................
         # Nested unions exercising edge cases induced by Python >= 3.8
         # optimizations leveraging PEP 572-style assignment expressions.
@@ -987,7 +1031,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=list[Union[int, str,]],
             pep_sign=HintSignList,
-            stdlib_type=list,
+            isinstanceable_type=list,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # List containing a mixture of integer and string constants.
@@ -1038,7 +1082,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Sequence[Union[str, ByteString]],
             pep_sign=HintSignSequence,
-            stdlib_type=Sequence,
+            isinstanceable_type=Sequence,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Sequence of string and bytestring constants.
@@ -1087,7 +1131,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=MutableSequence[Union[ByteString, Callable]],
             pep_sign=HintSignMutableSequence,
-            stdlib_type=MutableSequence,
+            isinstanceable_type=MutableSequence,
             is_pep585_builtin=True,
             piths_satisfied_meta=(
                 # Mutable sequence of string and bytestring constants.
