@@ -38,7 +38,6 @@ from beartype._data.hint.pep.sign.datapepsigns import (
     HintSignContextManager,
     HintSignDict,
     HintSignForwardRef,
-    HintSignGenerator,
     HintSignGeneric,
     HintSignHashable,
     HintSignList,
@@ -55,14 +54,23 @@ from beartype._data.hint.pep.sign.datapepsigns import (
     HintSignTypeVar,
     HintSignUnion,
 )
-from beartype._util.hint.pep.proposal.utilpep484 import (
-    HINT_PEP484_TYPE_FORWARDREF)
+from beartype._util.hint.pep.proposal.pep484.utilpep484ref import (
+    HINT_PEP484_FORWARDREF_TYPE)
 from beartype._util.py.utilpyversion import (
     IS_PYTHON_AT_LEAST_3_10,
     IS_PYTHON_AT_LEAST_3_9,
     IS_PYTHON_AT_LEAST_3_7,
     IS_PYTHON_3_6,
 )
+from beartype_test.a00_unit.data.data_type import (
+    Class,
+    Subclass,
+    SubclassSubclass,
+    OtherClass,
+    OtherSubclass,
+    # OtherSubclassSubclass,
+    context_manager_factory,
+)
 from beartype_test.a00_unit.data.hint.util.data_hintmetacls import (
     HintPithSatisfiedMetadata,
     HintPithUnsatisfiedMetadata,
@@ -71,8 +79,6 @@ from beartype_test.a00_unit.data.hint.util.data_hintmetacls import (
 from beartype_test.a00_unit.data.hint.util.data_hintmetatyping import (
     make_hints_metadata_typing)
 from collections import abc as collections_abc
-from contextlib import contextmanager
-from profile import Profile   # <-- class hopefully guaranteed to exist! *gulp*
 from typing import (
     Any,
     AnyStr,
@@ -82,7 +88,6 @@ from typing import (
     Container,
     ContextManager,
     Dict,
-    Generator,
     Generic,
     Hashable,
     IO,
@@ -102,16 +107,30 @@ from typing import (
     Union,
 )
 
-# ....................{ TYPEVARS                          }....................
+# ....................{ TYPEVARS ~ unbounded              }....................
 S = TypeVar('S')
 '''
-User-defined generic :mod:`typing` type variable.
+Arbitrary unbounded (i.e., universally applicable) type variable.
 '''
 
 
 T = TypeVar('T')
 '''
-User-defined generic :mod:`typing` type variable.
+Arbitrary unbounded (i.e., universally applicable) type variable.
+'''
+
+# ....................{ TYPEVARS ~ unbounded              }....................
+T_BOUNDED = TypeVar('T_BOUNDED', bound=int)
+'''
+Arbitrary **bounded type variable** (i.e., type variable parametrized by a
+PEP-compliant child type hint passed as the ``bound`` keyword argument).
+'''
+
+
+T_CONSTRAINED = TypeVar('T_CONSTRAINED', str, bytes)
+'''
+Arbitrary **constrained type variable** (i.e., type variable parametrized by
+two or more PEP-compliant child type hints passed as positional arguments).
 '''
 
 # ....................{ GENERICS ~ io                     }....................
@@ -245,37 +264,18 @@ class Pep484GenericTypevaredDeepMultiple(
     def __len__(self) -> bool:
         return len(self._iterable)
 
-# ....................{ PRIVATE ~ callables               }....................
-@contextmanager
-def _make_context_manager(obj: object) -> ContextManager[object]:
-    '''
-    Create and return a context manager trivially yielding the passed object.
-    '''
-
-    yield obj
+# ....................{ PRIVATE ~ forwardref              }....................
+_TEST_PEP484_FORWARDREF_CLASSNAME = (
+    'beartype_test.a00_unit.data.data_type.Subclass')
+'''
+Fully-qualified classname of an arbitrary class guaranteed to be importable.
+'''
 
 
-def _make_generator_yield_int_send_float_return_str() -> (
-    Generator[int, float, str]):
-    '''
-    Create and return a generator yielding integers, accepting floating-point
-    numbers sent to this generator by the caller, and returning strings.
-
-    See Also
-    ----------
-    https://www.python.org/dev/peps/pep-0484/#id39
-        ``echo_round`` function strongly inspiring this implementation, copied
-        verbatim from this subsection of :pep:`484`.
-    '''
-
-    # Initial value externally sent to this generator.
-    res = yield
-
-    while res:
-        res = yield round(res)
-
-    # Return a string constant.
-    return 'Unmarred, scarred revanent remnants'
+_TEST_PEP484_FORWARDREF_TYPE = Subclass
+'''
+Arbitrary class referred to by :data:`_PEP484_FORWARDREF_CLASSNAME`.
+'''
 
 # ....................{ ADDERS                            }....................
 def add_data(data_module: 'ModuleType') -> None:
@@ -289,16 +289,24 @@ def add_data(data_module: 'ModuleType') -> None:
         Module to be added to.
     '''
 
+    # ..................{ BOOLEANS                          }..................
     # True only if unsubscripted typing attributes (i.e., public attributes of
     # the "typing" module without arguments) are parametrized by one or more
     # type variables under the active Python interpreter.
     #
-    # This boolean is true for *ALL* Python interpreters targeting less than
-    # Python < 3.9. Prior to Python 3.9, the "typing" module parametrized most
-    # unsubscripted typing attributes by default. Python 3.9 halted that
-    # barbaric practice by leaving unsubscripted typing attributes
-    # unparametrized by default.
-    _IS_SIGN_TYPEVARED = not IS_PYTHON_AT_LEAST_3_9
+    # This boolean is true for Python interpreters targeting Python < 3.9.
+    # Prior to Python 3.9, the "typing" module parametrized most unsubscripted
+    # typing attributes by default. Python 3.9 halted that barbaric practice by
+    # leaving unsubscripted typing attributes unparametrized by default.
+    _IS_TYPEVARS_HIDDEN = not IS_PYTHON_AT_LEAST_3_9
+
+    # True only if unsubscripted typing attributes (i.e., public attributes of
+    # the "typing" module without arguments) are actually subscripted by one or
+    # more type variables under the active Python interpreter.
+    #
+    # This boolean is true for Python interpreters targeting 3.6 < Python <
+    # 3.9, oddly. (We don't make the rules. We simply complain about them.)
+    _IS_ARGS_HIDDEN = _IS_TYPEVARS_HIDDEN and not IS_PYTHON_3_6
 
     # ..................{ SETS                              }..................
     # Add PEP 484-specific shallowly ignorable test type hints to that set
@@ -357,7 +365,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=ByteString,
             pep_sign=HintSignByteString,
-            stdlib_type=collections_abc.ByteString,
+            isinstanceable_type=collections_abc.ByteString,
             piths_satisfied_meta=(
                 # Byte string constant.
                 HintPithSatisfiedMetadata(
@@ -402,13 +410,12 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # Unsubscripted forward reference defined as a simple string.
         HintPepMetadata(
-            hint='profile.Profile',
+            hint=_TEST_PEP484_FORWARDREF_CLASSNAME,
             pep_sign=HintSignForwardRef,
-            is_subscripted=False,
             is_type_typing=False,
             piths_satisfied_meta=(
-                # Profile object.
-                HintPithSatisfiedMetadata(Profile()),
+                # Instance of the class referred to by this reference.
+                HintPithSatisfiedMetadata(_TEST_PEP484_FORWARDREF_TYPE()),
             ),
             piths_unsatisfied_meta=(
                 # String object.
@@ -419,12 +426,12 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # Unsubscripted forward reference defined as a typing object.
         HintPepMetadata(
-            hint=HINT_PEP484_TYPE_FORWARDREF('profile.Profile'),
+            hint=HINT_PEP484_FORWARDREF_TYPE(
+                _TEST_PEP484_FORWARDREF_CLASSNAME),
             pep_sign=HintSignForwardRef,
-            is_subscripted=False,
             piths_satisfied_meta=(
-                # Profile object.
-                HintPithSatisfiedMetadata(Profile()),
+                # Instance of the class referred to by this reference.
+                HintPithSatisfiedMetadata(_TEST_PEP484_FORWARDREF_TYPE()),
             ),
             piths_unsatisfied_meta=(
                 # String object.
@@ -432,14 +439,13 @@ def add_data(data_module: 'ModuleType') -> None:
             ),
         ),
 
-        # ................{ UNSUBSCRIPTED ~ typevar           }................
-        # Generic type variable.
+        # ................{ UNSUBSCRIPTED ~ typevar : unbound }................
+        # Unbounded type variable.
         HintPepMetadata(
             hint=T,
             pep_sign=HintSignTypeVar,
             #FIXME: Remove after fully supporting type variables.
             is_ignorable=True,
-            is_subscripted=False,
             # Type variable instances are directly declared by the "typing"
             # module *ONLY* under Python 3.6.
             is_typing=IS_PYTHON_3_6,
@@ -449,33 +455,79 @@ def add_data(data_module: 'ModuleType') -> None:
                 # String constant.
                 HintPithSatisfiedMetadata('Oblate weapon Stacks (actually'),
             ),
-            # By definition, *ALL* objects satisfy *ALL* type variables.
+            # By definition, all objects satisfy all unbounded type variables.
             piths_unsatisfied_meta=(),
         ),
 
-        # String type variable.
+        # ................{ UNSUBSCRIPTED ~ typevar : bound   }................
+        # Constrained type variable declared by the "typing" module.
         HintPepMetadata(
             hint=AnyStr,
             pep_sign=HintSignTypeVar,
             #FIXME: Remove after fully supporting type variables.
             is_ignorable=True,
-            is_subscripted=False,
             piths_satisfied_meta=(
                 # String constant.
                 HintPithSatisfiedMetadata('We were mysteries, unwon'),
                 # Byte string constant.
                 HintPithSatisfiedMetadata(b'We donned apportionments'),
             ),
-            #FIXME: Uncomment after fully supporting type variables.
-            # piths_unsatisfied_meta=(
-            #     # Integer constant.
-            #     728,
-            #     # List of string constants.
-            #     HintPithUnsatisfiedMetadata([
-            #         'Of Politico‐policed diction maledictions,',
-            #         'Of that numeral addicts’ “—Additive game,” self‐',
-            #     ]),
-            # ),
+            piths_unsatisfied_meta=(
+                # Integer constant.
+                HintPithUnsatisfiedMetadata(0x8BADF00D),  # <-- 2343432205
+                # List of string constants.
+                HintPithUnsatisfiedMetadata([
+                    'Of Politico‐policed diction maledictions,',
+                    'Of that numeral addicts’ “—Additive game,” self‐',
+                ]),
+            ),
+        ),
+
+        # User-defined constrained type variable.
+        HintPepMetadata(
+            hint=T_CONSTRAINED,
+            pep_sign=HintSignTypeVar,
+            #FIXME: Remove after fully supporting type variables.
+            is_ignorable=True,
+            is_typing=IS_PYTHON_3_6,
+            piths_satisfied_meta=(
+                # String constant.
+                HintPithSatisfiedMetadata('Prim (or'),
+                # Byte string constant.
+                HintPithSatisfiedMetadata(
+                    b'Primely positional) Quality inducements'),
+            ),
+            piths_unsatisfied_meta=(
+                # Integer constant.
+                HintPithUnsatisfiedMetadata(0xABADBABE),  # <-- 2880289470
+                # List of string constants.
+                HintPithUnsatisfiedMetadata([
+                    'Into lavishly crested, crestfallen ',
+                    'epaulette‐cross‐pollinated st‐Ints,',
+                ]),
+            ),
+        ),
+
+        # User-defined bounded type variable.
+        HintPepMetadata(
+            hint=T_BOUNDED,
+            pep_sign=HintSignTypeVar,
+            #FIXME: Remove after fully supporting type variables.
+            is_ignorable=True,
+            is_typing=IS_PYTHON_3_6,
+            piths_satisfied_meta=(
+                # Integer constant.
+                HintPithSatisfiedMetadata(0x0B00B135),  # <-- 184594741
+            ),
+            piths_unsatisfied_meta=(
+                # String constant.
+                HintPithUnsatisfiedMetadata(
+                    'Light‐expectorating, aspectant '
+                    'thujone‐inspecting enswathement of'
+                ),
+                # List of integer constants.
+                HintPithUnsatisfiedMetadata([0xBAAAAAAD, 0xBADDCAFE,]),
+            ),
         ),
 
         # ................{ CALLABLE                          }................
@@ -483,7 +535,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Callable[[], str],
             pep_sign=HintSignCallable,
-            stdlib_type=collections_abc.Callable,
+            isinstanceable_type=collections_abc.Callable,
             piths_satisfied_meta=(
                 # Lambda function returning a string constant.
                 HintPithSatisfiedMetadata(lambda: 'Eudaemonia.'),
@@ -499,11 +551,11 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=ContextManager[str],
             pep_sign=HintSignContextManager,
-            stdlib_type=contextlib.AbstractContextManager,
+            isinstanceable_type=contextlib.AbstractContextManager,
             piths_satisfied_meta=(
                 # Context manager.
                 HintPithSatisfiedMetadata(
-                    pith=lambda: _make_context_manager(
+                    pith=lambda: context_manager_factory(
                         'We were mysteries, unwon'),
                     is_context_manager=True,
                     is_pith_factory=True,
@@ -520,8 +572,9 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Dict,
             pep_sign=HintSignDict,
-            is_typevared=_IS_SIGN_TYPEVARED,
-            stdlib_type=dict,
+            is_args=_IS_ARGS_HIDDEN,
+            is_typevars=_IS_TYPEVARS_HIDDEN,
+            isinstanceable_type=dict,
             piths_satisfied_meta=(
                 # Dictionary containing arbitrary key-value pairs.
                 HintPithSatisfiedMetadata({
@@ -542,7 +595,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Dict[int, str],
             pep_sign=HintSignDict,
-            stdlib_type=dict,
+            isinstanceable_type=dict,
             piths_satisfied_meta=(
                 # Dictionary mapping integer keys to string values.
                 HintPithSatisfiedMetadata({
@@ -561,8 +614,8 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Dict[S, T],
             pep_sign=HintSignDict,
-            is_typevared=True,
-            stdlib_type=dict,
+            isinstanceable_type=dict,
+            is_typevars=True,
             piths_satisfied_meta=(
                 # Dictionary mapping string keys to integer values.
                 HintPithSatisfiedMetadata({
@@ -577,22 +630,9 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # ................{ GENERATOR                         }................
-        # Flat generator.
-        HintPepMetadata(
-            hint=Generator[int, float, str],
-            pep_sign=HintSignGenerator,
-            stdlib_type=collections_abc.Generator,
-            piths_satisfied_meta=(
-                # Generator yielding integers, accepting floating-point numbers
-                # sent to this generator by the caller, and returning strings.
-                HintPithSatisfiedMetadata(
-                    _make_generator_yield_int_send_float_return_str()),
-            ),
-            piths_unsatisfied_meta=(
-                # Lambda function returning a string constant.
-                HintPithUnsatisfiedMetadata(lambda: 'Cessation'),
-            ),
-        ),
+        # Note that testing generators requires creating generators, which
+        # require a different syntax to that of standard callables; ergo,
+        # generator type hints are tested elsewhere.
 
         # ................{ GENERICS ~ single                 }................
         # Generic subclassing a single unsubscripted "typing" type.
@@ -600,7 +640,7 @@ def add_data(data_module: 'ModuleType') -> None:
             hint=Pep484GenericUnsubscriptedSingle,
             pep_sign=HintSignGeneric,
             generic_type=Pep484GenericUnsubscriptedSingle,
-            is_subscripted=False,
+            # is_args=False,
             is_type_typing=False,
             piths_satisfied_meta=(
                 # Subclass-specific generic list of string constants.
@@ -626,7 +666,7 @@ def add_data(data_module: 'ModuleType') -> None:
             hint=Pep484GenericUntypevaredSingle,
             pep_sign=HintSignGeneric,
             generic_type=Pep484GenericUntypevaredSingle,
-            is_subscripted=False,
+            # is_args=True,
             is_type_typing=False,
             piths_satisfied_meta=(
                 # Subclass-specific generic list of string constants.
@@ -652,7 +692,7 @@ def add_data(data_module: 'ModuleType') -> None:
             hint=Pep484GenericTypevaredSingle,
             pep_sign=HintSignGeneric,
             generic_type=Pep484GenericTypevaredSingle,
-            is_typevared=True,
+            is_typevars=True,
             is_type_typing=False,
             piths_satisfied_meta=(
                 # Subclass-specific generic.
@@ -673,7 +713,7 @@ def add_data(data_module: 'ModuleType') -> None:
             hint=Pep484GenericTypevaredSingle[S, T],
             pep_sign=HintSignGeneric,
             generic_type=Pep484GenericTypevaredSingle,
-            is_typevared=True,
+            is_typevars=True,
             # The type of subscripted PEP 484-compliant generics is:
             # * Under Python >= 3.7.0, "typing".
             # * Under Python 3.6.x, the module defining those generics.
@@ -699,7 +739,6 @@ def add_data(data_module: 'ModuleType') -> None:
             hint=Pep484GenericUntypevaredMultiple,
             pep_sign=HintSignGeneric,
             generic_type=Pep484GenericUntypevaredMultiple,
-            is_subscripted=False,
             is_type_typing=False,
             piths_satisfied_meta=(
                 # Subclass-specific generic 2-tuple of string constants.
@@ -724,7 +763,8 @@ def add_data(data_module: 'ModuleType') -> None:
             hint=Pep484GenericTypevaredShallowMultiple,
             pep_sign=HintSignGeneric,
             generic_type=Pep484GenericTypevaredShallowMultiple,
-            is_typevared=True,
+            # is_args=False,
+            is_typevars=True,
             is_type_typing=False,
             piths_satisfied_meta=(
                 # Subclass-specific generic iterable of string constants.
@@ -747,7 +787,8 @@ def add_data(data_module: 'ModuleType') -> None:
             hint=Pep484GenericTypevaredDeepMultiple,
             pep_sign=HintSignGeneric,
             generic_type=Pep484GenericTypevaredDeepMultiple,
-            is_typevared=True,
+            # is_args=False,
+            is_typevars=True,
             is_type_typing=False,
             piths_satisfied_meta=(
                 # Subclass-specific generic iterable of 2-tuples of string
@@ -775,7 +816,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=List[Pep484GenericUntypevaredMultiple],
             pep_sign=HintSignList,
-            stdlib_type=list,
+            isinstanceable_type=list,
             piths_satisfied_meta=(
                 # List of subclass-specific generic 2-tuples of string
                 # constants.
@@ -809,8 +850,9 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=List,
             pep_sign=HintSignList,
-            stdlib_type=list,
-            is_typevared=_IS_SIGN_TYPEVARED,
+            isinstanceable_type=list,
+            is_args=_IS_ARGS_HIDDEN,
+            is_typevars=_IS_TYPEVARS_HIDDEN,
             piths_satisfied_meta=(
                 # Empty list, which satisfies all hint arguments by definition.
                 HintPithSatisfiedMetadata([]),
@@ -837,7 +879,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=List[object],
             pep_sign=HintSignList,
-            stdlib_type=list,
+            isinstanceable_type=list,
             piths_satisfied_meta=(
                 # Empty list, which satisfies all hint arguments by definition.
                 HintPithSatisfiedMetadata([]),
@@ -859,7 +901,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=List[str],
             pep_sign=HintSignList,
-            stdlib_type=list,
+            isinstanceable_type=list,
             piths_satisfied_meta=(
                 # Empty list, which satisfies all hint arguments by definition.
                 HintPithSatisfiedMetadata([]),
@@ -893,8 +935,8 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=List[T],
             pep_sign=HintSignList,
-            stdlib_type=list,
-            is_typevared=True,
+            isinstanceable_type=list,
+            is_typevars=True,
             piths_satisfied_meta=(
                 # Empty list, which satisfies all hint arguments by definition.
                 HintPithSatisfiedMetadata([]),
@@ -916,7 +958,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=NewType('TotallyNotAStr', str),
             pep_sign=HintSignNewType,
-            is_subscripted=False,
+            # is_args=False,
             # "typing.NewType" type hints are always declared by that module.
             is_typing=True,
             # If the active Python interpreter targets:
@@ -944,8 +986,9 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Match,
             pep_sign=HintSignMatch,
-            stdlib_type=RegexMatchType,
-            is_typevared=_IS_SIGN_TYPEVARED,
+            isinstanceable_type=RegexMatchType,
+            is_args=_IS_TYPEVARS_HIDDEN,  # <--- don't ask
+            is_typevars=_IS_TYPEVARS_HIDDEN,
             piths_satisfied_meta=(
                 # Regular expression match of one or more string constants.
                 HintPithSatisfiedMetadata(re.search(
@@ -964,7 +1007,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Match[str],
             pep_sign=HintSignMatch,
-            stdlib_type=RegexMatchType,
+            isinstanceable_type=RegexMatchType,
             piths_satisfied_meta=(
                 # Regular expression match of one or more string constants.
                 HintPithSatisfiedMetadata(re.search(
@@ -983,8 +1026,9 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Pattern,
             pep_sign=HintSignPattern,
-            stdlib_type=RegexCompiledType,
-            is_typevared=_IS_SIGN_TYPEVARED,
+            isinstanceable_type=RegexCompiledType,
+            is_args=_IS_TYPEVARS_HIDDEN,  # <--- don't ask
+            is_typevars=_IS_TYPEVARS_HIDDEN,
             piths_satisfied_meta=(
                 # Regular expression string pattern.
                 HintPithSatisfiedMetadata(
@@ -1000,7 +1044,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Pattern[str],
             pep_sign=HintSignPattern,
-            stdlib_type=RegexCompiledType,
+            isinstanceable_type=RegexCompiledType,
             piths_satisfied_meta=(
                 # Regular expression string pattern.
                 HintPithSatisfiedMetadata(
@@ -1012,6 +1056,127 @@ def add_data(data_module: 'ModuleType') -> None:
             ),
         ),
 
+        # ................{ SUBCLASS                          }................
+        # Unsubscripted "Type" singleton.
+        HintPepMetadata(
+            hint=Type,
+            pep_sign=HintSignType,
+            isinstanceable_type=type,
+            is_args=_IS_ARGS_HIDDEN,
+            is_typevars=_IS_TYPEVARS_HIDDEN,
+            piths_satisfied_meta=(
+                # Transitive superclass of all superclasses.
+                HintPithSatisfiedMetadata(object),
+                # Arbitrary class.
+                HintPithSatisfiedMetadata(str),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant.
+                HintPithUnsatisfiedMetadata('Samely:'),
+            ),
+        ),
+
+        # Any type, semantically equivalent under PEP 484 to the unsubscripted
+        # "Type" singleton.
+        HintPepMetadata(
+            hint=Type[Any],
+            pep_sign=HintSignType,
+            isinstanceable_type=type,
+            piths_satisfied_meta=(
+                # Arbitrary class.
+                HintPithSatisfiedMetadata(bool),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant.
+                HintPithUnsatisfiedMetadata('Coulomb‐lobed lobbyist’s Ģom'),
+            ),
+        ),
+
+        # "type" superclass, semantically equivalent to the unsubscripted
+        # "Type" singleton.
+        HintPepMetadata(
+            hint=Type[type],
+            pep_sign=HintSignType,
+            isinstanceable_type=type,
+            piths_satisfied_meta=(
+                # Arbitrary class.
+                HintPithSatisfiedMetadata(complex),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant.
+                HintPithUnsatisfiedMetadata('Had al-'),
+            ),
+        ),
+
+        # Specific class.
+        HintPepMetadata(
+            hint=Type[Class],
+            pep_sign=HintSignType,
+            isinstanceable_type=type,
+            piths_satisfied_meta=(
+                # Subclass of this class.
+                HintPithSatisfiedMetadata(Subclass),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant.
+                HintPithUnsatisfiedMetadata('Namely,'),
+                # Non-subclass of this class.
+                HintPithUnsatisfiedMetadata(str),
+            ),
+        ),
+
+        # Specific class deferred with a forward reference.
+        HintPepMetadata(
+            hint=Type[_TEST_PEP484_FORWARDREF_CLASSNAME],
+            pep_sign=HintSignType,
+            isinstanceable_type=type,
+            piths_satisfied_meta=(
+                # Subclass of this class.
+                HintPithSatisfiedMetadata(SubclassSubclass),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant.
+                HintPithUnsatisfiedMetadata('Jabbar‐disbarred'),
+                # Non-subclass of this class.
+                HintPithUnsatisfiedMetadata(dict),
+            ),
+        ),
+
+        # Two or more specific classes.
+        HintPepMetadata(
+            hint=Type[Union[Class, OtherClass,]],
+            pep_sign=HintSignType,
+            isinstanceable_type=type,
+            piths_satisfied_meta=(
+                # Arbitrary subclass of one class subscripting this hint.
+                HintPithSatisfiedMetadata(Subclass),
+                # Arbitrary subclass of another class subscripting this hint.
+                HintPithSatisfiedMetadata(OtherSubclass),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant.
+                HintPithUnsatisfiedMetadata('Jabberings'),
+                # Non-subclass of any classes subscripting this hint.
+                HintPithUnsatisfiedMetadata(set),
+            ),
+        ),
+
+        # Generic class.
+        HintPepMetadata(
+            hint=Type[T],
+            pep_sign=HintSignType,
+            isinstanceable_type=type,
+            is_typevars=True,
+            piths_satisfied_meta=(
+                # Arbitrary class.
+                HintPithSatisfiedMetadata(int),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant.
+                HintPithUnsatisfiedMetadata('Obligation, and'),
+            ),
+        ),
+
         # ................{ TUPLE                             }................
         # Unsubscripted "Tuple" attribute. Note that this attribute is *NOT*
         # parametrized by one or more type variables under any Python version,
@@ -1020,7 +1185,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Tuple,
             pep_sign=HintSignTuple,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
             piths_satisfied_meta=(
                 # Tuple containing arbitrary items.
                 HintPithSatisfiedMetadata((
@@ -1038,9 +1203,9 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # ................{ TUPLE ~ fixed                     }................
-        # Empty tuple. Yes, this is ridiculous, useless, and non-orthogonal with
-        # standard sequence syntax, which supports no comparable notion of an
-        # "empty {insert-standard-sequence-here}" (e.g., empty list). For example:
+        # Empty tuple. Yes, this is ridiculous, useless, and non-orthogonal
+        # with standard sequence syntax, which supports no comparable notion of
+        # an "empty {insert-type-here}" (e.g., empty list). For example:
         #     >>> import typing
         #     >>> List[()]
         #     TypeError: Too few parameters for List; actual 0, expected 1
@@ -1049,7 +1214,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Tuple[()],
             pep_sign=HintSignTuple,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
             piths_satisfied_meta=(
                 # Empty tuple.
                 HintPithSatisfiedMetadata(()),
@@ -1074,7 +1239,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Tuple[Any, object,],
             pep_sign=HintSignTuple,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
             piths_satisfied_meta=(
                 # Tuple containing arbitrary items.
                 HintPithSatisfiedMetadata((
@@ -1099,7 +1264,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Tuple[float, Any, str,],
             pep_sign=HintSignTuple,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
             piths_satisfied_meta=(
                 # Tuple containing a floating-point number, string, and integer
                 # (in that exact order).
@@ -1148,7 +1313,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Tuple[Tuple[float, Any, str,], ...],
             pep_sign=HintSignTuple,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
             piths_satisfied_meta=(
                 # Tuple containing tuples containing a floating-point number,
                 # string, and integer (in that exact order).
@@ -1200,8 +1365,8 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Tuple[S, T],
             pep_sign=HintSignTuple,
-            is_typevared=True,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
+            is_typevars=True,
             piths_satisfied_meta=(
                 # Tuple containing a floating-point number and string (in that
                 # exact order).
@@ -1225,7 +1390,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Tuple[str, ...],
             pep_sign=HintSignTuple,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
             piths_satisfied_meta=(
                 # Tuple containing arbitrarily many string constants.
                 HintPithSatisfiedMetadata((
@@ -1258,8 +1423,8 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Tuple[T, ...],
             pep_sign=HintSignTuple,
-            is_typevared=True,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
+            is_typevars=True,
             piths_satisfied_meta=(
                 # Tuple containing arbitrarily many string constants.
                 HintPithSatisfiedMetadata((
@@ -1274,56 +1439,6 @@ def add_data(data_module: 'ModuleType') -> None:
             ),
         ),
 
-        # ................{ TYPE                              }................
-        # Unsubscripted "Type" singleton.
-        HintPepMetadata(
-            hint=Type,
-            pep_sign=HintSignType,
-            is_typevared=_IS_SIGN_TYPEVARED,
-            stdlib_type=type,
-            piths_satisfied_meta=(
-                # Transitive superclass of all superclasses.
-                HintPithSatisfiedMetadata(object),
-                # Builtin class.
-                HintPithSatisfiedMetadata(str),
-            ),
-            piths_unsatisfied_meta=(
-                # String constant.
-                HintPithUnsatisfiedMetadata('Samely:'),
-            ),
-        ),
-
-        # Builtin type.
-        HintPepMetadata(
-            hint=Type[dict],
-            pep_sign=HintSignType,
-            stdlib_type=type,
-            piths_satisfied_meta=(
-                # Builtin "dict" class itself.
-                HintPithSatisfiedMetadata(dict),
-            ),
-            piths_unsatisfied_meta=(
-                # String constant.
-                HintPithUnsatisfiedMetadata('Namely,'),
-            ),
-        ),
-
-        # Generic type.
-        HintPepMetadata(
-            hint=Type[T],
-            pep_sign=HintSignType,
-            is_typevared=True,
-            stdlib_type=type,
-            piths_satisfied_meta=(
-                # Builtin "int" class itself.
-                HintPithSatisfiedMetadata(int),
-            ),
-            piths_unsatisfied_meta=(
-                # String constant.
-                HintPithUnsatisfiedMetadata('Obligation, and'),
-            ),
-        ),
-
         # ................{ UNION                             }................
         # Note that unions of one argument (e.g., "Union[str]") *CANNOT* be
         # listed here, as the "typing" module implicitly reduces these unions
@@ -1501,7 +1616,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Union[str, Iterable[Tuple[S, T]]],
             pep_sign=HintSignUnion,
-            is_typevared=True,
+            is_typevars=True,
         ),
 
         # ................{ UNION ~ nested                    }................
@@ -1512,7 +1627,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=List[Union[int, str,]],
             pep_sign=HintSignList,
-            stdlib_type=list,
+            isinstanceable_type=list,
             piths_satisfied_meta=(
                 # List containing a mixture of integer and string constants.
                 HintPithSatisfiedMetadata([
@@ -1562,7 +1677,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Sequence[Union[str, ByteString]],
             pep_sign=HintSignSequence,
-            stdlib_type=collections_abc.Sequence,
+            isinstanceable_type=collections_abc.Sequence,
             piths_satisfied_meta=(
                 # Sequence of string and bytestring constants.
                 HintPithSatisfiedMetadata((
@@ -1610,7 +1725,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=MutableSequence[Union[ByteString, Callable]],
             pep_sign=HintSignMutableSequence,
-            stdlib_type=collections_abc.MutableSequence,
+            isinstanceable_type=collections_abc.MutableSequence,
             piths_satisfied_meta=(
                 # Mutable sequence of string and bytestring constants.
                 HintPithSatisfiedMetadata([
@@ -1722,7 +1837,7 @@ def add_data(data_module: 'ModuleType') -> None:
             HintPepMetadata(
                 hint=Hashable,
                 pep_sign=HintSignHashable,
-                stdlib_type=collections_abc.Hashable,
+                isinstanceable_type=collections_abc.Hashable,
                 piths_satisfied_meta=(
                     # String constant.
                     HintPithSatisfiedMetadata(
@@ -1746,7 +1861,7 @@ def add_data(data_module: 'ModuleType') -> None:
             HintPepMetadata(
                 hint=Sized,
                 pep_sign=HintSignSized,
-                stdlib_type=collections_abc.Sized,
+                isinstanceable_type=collections_abc.Sized,
                 piths_satisfied_meta=(
                     # String constant.
                     HintPithSatisfiedMetadata('Faire, a'),
