@@ -7,10 +7,7 @@
 **Project-wide functional static type-checker tests.**
 
 This submodule functionally tests the this project's compliance with
-third-party static type-checkers and hence `PEP 561`_.
-
-.. _PEP 561:
-    https://www.python.org/dev/peps/pep-0561
+third-party static type-checkers and hence :pep:`561`.
 '''
 
 # ....................{ IMPORTS                           }....................
@@ -58,12 +55,9 @@ from beartype_test.util.mark.pytskip import (
 @skip_if_pypy()
 def test_pep561_mypy() -> None:
     '''
-    Functional test testing this project's compliance with `PEP 561`_ by
-    externally running MyPy_, the most popular third-party static type checker
-    as of this test, against this project's top-level package.
-
-    .. _PEP 561:
-        https://www.python.org/dev/peps/pep-0561
+    Functional test testing this project's compliance with :pep:`561` by
+    externally running :mod:`mypy`, the most popular third-party static type
+    checker as of this test, against this project's top-level package.
     '''
 
     # Defer heavyweight imports.
